@@ -26,10 +26,10 @@ Action bag class for actions storing
 @author: Alexander Kulikov
 '''
 
-from hivemind.attribute import *
-from PySide.QtCore import *
-from PySide.QtGui import *
-from hivemind.gui_widgets import *
+from hivemind.attribute import readable
+from PySide.QtCore import QObject, Qt
+from PySide.QtGui import QKeySequence, QAction, QIcon
+from hivemind.gui_widgets import StatusAction
 
 class ActionBag(QObject):
     '''
@@ -42,8 +42,7 @@ class ActionBag(QObject):
              'fileSaveAsAction', 'editEdgeAction', 'editLabelAction', 'editNodeAction',
              'editNodeIconsAction', 'foldNodeAction', 'addNodeAction',
              'addSiblingNodeBelowAction', 'removeNodeAction', 'enterTransferModeAction',
-             'undoAction', 'redoAction', 'startNetworkClientAction',
-             'startNetworkServerAction', 'stopNetworkAction', 'zoomInAction',
+             'undoAction', 'redoAction', 'zoomInAction',
              'zoomOutAction', 'exitAction', 'aboutAction', 'settingsAction',
              'parentWidthAction', 'thinWidthAction', 'oneWidthAction', 'twoWidthAction',
              'fourWidthAction', 'eightWidthAction', 'parentStyleAction',
@@ -51,8 +50,9 @@ class ActionBag(QObject):
              'sharpBezierStyleAction', 'connectionStatusAction', 'subscribeStatusAction',
              'addSiblingNodeAboveAction', 'editAffiliationAction',
              'cancelTransferModeAction', 'putNodeAction', 'putNodeBelowAction',
-             'putNodeAboveAction', 'stopNetworkAction', 'connectXMPPAction',
-             'stopProtocolAction', 'startPubSubServiceAction', 'startPubSubClientAction')
+             'putNodeAboveAction', 'connectXMPPAction', 'disconnectXMPPAction',
+             'createServiceAction', 'createClientAction', 'stopProtocolAction',
+             'startServiceAction', 'startClientAction')
 
     def __init__(self, parent = None):
         QObject.__init__(self, parent)
@@ -62,11 +62,14 @@ class ActionBag(QObject):
     def _createActions(self):
         '''Create actions'''
         #pylint: disable=W0201,R0915
-        self.__fileNewAction = self.createAction(self.tr('&New'), 'Ctrl+N', 'document-new')
-        self.__fileOpenAction = self.createAction(self.tr('&Open'), 'Ctrl+O', 'document-open')
-        self.__fileSaveAction = self.createAction(self.tr('&Save'), 'Ctrl+S', 'document-save')
+        self.__fileNewAction = self.createAction(self.tr('&New'), QKeySequence.New,
+                'document-new')
+        self.__fileOpenAction = self.createAction(self.tr('&Open'), QKeySequence.Open,
+                'document-open')
+        self.__fileSaveAction = self.createAction(self.tr('&Save'), QKeySequence.Save,
+                'document-save')
         self.__fileSaveAsAction = self.createAction(self.tr('Save as'),
-                None, 'document-save-as')
+                QKeySequence.SaveAs, 'document-save-as')
         self.__editEdgeAction = self.createAction(self.tr('Edit edge'), 'Ctrl+E')
         self.__editLabelAction = self.createAction(self.tr('Edit label'), 'Ctrl+L')
         self.__editNodeAction = self.createAction(self.tr('Edit node'), 'F2', 'document-edit')
@@ -79,7 +82,7 @@ class ActionBag(QObject):
         self.__addSiblingNodeAboveAction = self.createAction(self.tr('New sibling node above'),
                 'Shift+Return', 'list-add')
         self.__removeNodeAction = self.createAction(self.tr('Remove node'),
-                'Delete', 'list-remove')
+                QKeySequence.Delete, 'list-remove')
         self.__enterTransferModeAction = self.createAction(self.tr('Move node'), 'Ctrl+M')
         self.__cancelTransferModeAction = self.createAction(self.tr('Cancel transfer mode'),
                 'Escape')
@@ -87,22 +90,19 @@ class ActionBag(QObject):
         self.__putNodeBelowAction = self.createAction(self.tr('Put node below'), 'Return')
         self.__putNodeAboveAction = self.createAction(self.tr('Put node above'),
                 'Shift+Return')
-        self.__undoAction = self.createAction(self.tr('&Undo'), 'Ctrl+Z', 'edit-undo')
-        self.__redoAction = self.createAction(self.tr('&Redo'), 'Ctrl+Y', 'edit-redo')
-        self.__startNetworkServerAction = self.createAction(self.tr('&Share mind map'))
-        self.__startNetworkClientAction = self.createAction(self.tr('&Edit shared mind map'))
-        self.__connectXMPPAction = self.createAction(self.tr('&Connect to XMPP network'))
-        self.__startPubSubServiceAction = self.createAction(self.tr('S&tart server'))
-        self.__startPubSubClientAction = self.createAction(self.tr('C&onnect to server'))
-        self.__stopNetworkAction = self.createAction(self.tr('&Disconnect from XMPP network'))
-        self.__stopProtocolAction = self.createAction(self.tr('&Finish collaboration'))
-        self.__zoomInAction = self.createAction(self.tr('Zoom in'), '+', 'zoom-in')
-        self.__zoomOutAction = self.createAction(self.tr('Zoom out'), '-', 'zoom-out')
+        self.__undoAction = self.createAction(self.tr('&Undo'), QKeySequence.Undo,
+                'edit-undo')
+        self.__redoAction = self.createAction(self.tr('&Redo'), QKeySequence.Redo,
+                'edit-redo')
+        self.__zoomInAction = self.createAction(self.tr('Zoom in'), QKeySequence.ZoomIn,
+                'zoom-in')
+        self.__zoomOutAction = self.createAction(self.tr('Zoom out'),
+                QKeySequence.ZoomOut, 'zoom-out')
         self.__aboutAction = self.createAction(self.tr('&About'), None, 'help-about')
         self.__exitAction = self.createAction(self.tr('E&xit'),
-                'Ctrl+Q', 'application-exit')
+                QKeySequence.Quit, 'application-exit')
         self.__settingsAction = self.createAction(self.tr('Settings'),
-                None, 'preferences-other')
+                QKeySequence.Preferences, 'preferences-other')
         self.__parentWidthAction = self.createAction(self.tr('Parent'))
         self.__thinWidthAction = self.createAction(self.tr('Thin'))
         self.__oneWidthAction = self.createAction('1')
@@ -117,6 +117,13 @@ class ActionBag(QObject):
         self.__connectionStatusAction = StatusAction('Connection status', 'connection', 'no')
         self.__subscribeStatusAction = StatusAction('Subscribe status', 'subscribe', 'no')
         self.__editAffiliationAction = self.createAction(self.tr('&Edit participants access'))
+        self.__connectXMPPAction = self.createAction(self.tr('&Connect to XMPP'))
+        self.__disconnectXMPPAction = self.createAction(self.tr('&Disconnect from XMPP'))
+        self.__createServiceAction = self.createAction(self.tr('&Create service'))
+        self.__createClientAction = self.createAction(self.tr('&Create client'))
+        self.__stopProtocolAction = self.createAction(self.tr('&Disconnect from network'))
+        self.__startServiceAction = self.createAction(self.tr('&Start network service'))
+        self.__startClientAction = self.createAction(self.tr('&Start network client'))
 
     def _initializeActions(self):
         '''Make specific action initializations'''
