@@ -97,6 +97,7 @@ def _attribute(permission, propNames, propNamesWithDoc, signalName = None):
         classDict[attrName] = _property(className, attrName, permission, doc, signalName)
 
 def _property(className, attrName, permission, doc, signalName):
+    #pylint: disable=C0111,E0102
     '''Generate class property with specified parameters'''
     mangledName = _mangle(className, attrName)
     fget, fset, fdel = None, None, None
@@ -119,7 +120,7 @@ def _property(className, attrName, permission, doc, signalName):
         doc += ('.\nEmits B{%s} signal on change' % signalName)
     return property(fget = fget, fset = fset, fdel = fdel, doc = doc)
 
-def adaptCallable(callable):
+def adaptCallable(callableObject):
     '''
     Create an adapter function forwarding its call to the certain
     callable object
@@ -127,9 +128,7 @@ def adaptCallable(callable):
     @param callable: callable object to forward calls
     @rtype: function
     '''
-    def adapter(*args):
-        return callable(*args)
-    return adapter
+    return lambda *args: callableObject(*args)
 
 class Observable():
     '''
@@ -155,7 +154,7 @@ class Observable():
     
     @author: Andrew Vasilev
     '''
-    def __init__(self, *args):
+    def __init__(self):
         '''
         Constructor
         '''
