@@ -26,9 +26,10 @@ Core classes
 
 import hivemind.settings as settings
 import time
-from PySide.QtGui import *
-from PySide.QtCore import *
-from hivemind.attribute import *
+from PySide.QtGui import QApplication, QFontMetricsF, QPalette, QTextDocument, \
+ QAbstractTextDocumentLayout
+from PySide.QtCore import QSizeF
+from hivemind.attribute import Observable, readable, writable
 
 
 class Element(object):
@@ -37,6 +38,8 @@ class Element(object):
 
     @authors: Andrew Golovchenko
     '''
+    #pylint: disable=W0212
+
     _ATTRIBUTES = ()
     '''List of element attributes'''
 
@@ -145,34 +148,44 @@ class Node(Element, Observable):
 
     @authors: Ilya Paramonov, Andrew Golovchenko, Andrew Vasilev
     '''
+    #pylint: disable=W0212
+
     _ATTRIBUTES = ('created', 'id', 'modified', 'style', 'left', 'folded', 'link', 'hgap',
-                'vgap', 'vshift', 'encrypted_content', 'background_color', 'color')
+                'vgap', 'vshift', 'encrypted_content', 'backgroundColor', 'color',
+                'propagateNodeFormatting')
     '''List of node attributes'''
     readable('created', 'id', 'modified', 'encrypted_content', 'nodeAttribute', 'note',
              'parent', 'icons', 'children', 'font', 'color', 'edgeColor',
              'edgeWidth', 'edgeStyle', 'hgap', 'vgap', 'vshift', 'cloud', 'folded',
-             'background_color', 'link', 'style', 'left',
-             'labelText', 'labelFont', 'labelColor')
+             'backgroundColor', 'link', 'style', 'left',
+             'labelText', 'labelFont', 'labelColor', 'propagateNodeFormatting',
+             'propagateLabelFormatting')
 
     def _setStyle(self, style):
         '''Set style value of Node'''
         self.__style = style
-        self._propagateEffectiveStyle(style)
+        self._propagateParentStyle()
+
+    def _propagateParentStyle(self):
+        '''Store and send to children current parent style attribute'''
+        if self.__style:
+            newParentStyle = self.__style
+        else:
+            newParentStyle = self.__parentStyle
+        for child in self.__children:
+            if child.__parentStyle == newParentStyle: continue
+            child.__parentStyle = newParentStyle
+            child._propagateParentStyle()
 
     @property
     def effectiveStyle(self):
         '''Style of the node witch should be used to draw the node'''
-        return self.__effectiveStyle if self.__effectiveStyle else settings.get('defaultStyle')
-
-    def _propagateEffectiveStyle(self, style):
-        '''Set style value of Node according inheritance policy'''
-        if self.__effectiveStyle == style: return
         if self.__style:
-            self.__effectiveStyle = self.__style
+            return self.__style
+        elif self.__parentStyle:
+            return self.__parentStyle
         else:
-            self.__effectiveStyle = self.__parent.__effectiveStyle if self.__parent else style
-        for child in self.__children:
-            child._propagateEffectiveStyle(self.__effectiveStyle)
+            return settings.get('defaultStyle')
 
     def _setLeft(self, left):
         '''Set left position flag of Node according inheritance policy'''
@@ -184,219 +197,242 @@ class Node(Element, Observable):
     def _setLabelColor(self, color):
         '''Set label color attribute to Node'''
         self.__labelColor = color
-        self._propagateEffectiveLabelColor(color)
+        self._propagateParentLabelColor()
+
+    def _propagateParentLabelColor(self):
+        '''Store and send to children parent label color attribute'''
+        if self.__labelColor and self.__propagateLabelFormatting:
+            newParentLabelColor = self.__labelColor
+        else:
+            newParentLabelColor = self.__parentLabelColor
+        for child in self.__children:
+            if equal(child.__parentLabelColor, newParentLabelColor): continue
+            child.__parentLabelColor = newParentLabelColor
+            child._propagateParentLabelColor()
 
     @property
     def effectiveLabelColor(self):
         '''Color of the label that should be used to draw the node'''
-        if self.__effectiveLabelColor is not None:
-            return self.__effectiveLabelColor
+        if self.__labelColor:
+            return self.__labelColor
+        elif self.__parentLabelColor:
+            return self.__parentLabelColor
         else:
             return settings.get('defaultLabelColor')
 
-    def _propagateEffectiveLabelColor(self, color):
-        '''Set label color attribute to Node according inheritance policy'''
-        if equal(self.__effectiveLabelColor, color): return
-        if self.__labelColor:
-            self.__effectiveLabelColor = self.__labelColor
-        elif self.__parent:
-            self.__effectiveLabelColor = self.__parent.__effectiveLabelColor
-        else:
-            self.__effectiveLabelColor = color
-        if self.__effectiveLabelColor is not None:
-            self.__effectiveLabelColor = QColor(self.__effectiveLabelColor)
-        for child in self.__children:
-            child._propagateEffectiveLabelColor(self.__effectiveLabelColor)
-
     def _setLabelFont(self, font):
         '''Set label font attribute to Node'''
         self.__labelFont = font
-        self._propagateEffectiveLabelFont(font)
+        self._propagateParentLabelFont()
+
+    def _propagateParentLabelFont(self):
+        '''Set label font attribute to Node according inheritance policy'''
+        self.__labelFontMetrics = QFontMetricsF(self.effectiveLabelFont)
+        if self.__labelFont and self.__propagateLabelFormatting:
+            newParentLabelFont = self.__labelFont
+        else:
+            newParentLabelFont = self.__parentLabelFont
+        for child in self.__children:
+            if equal(child.__parentLabelFont, newParentLabelFont): continue
+            child.__parentLabelFont = newParentLabelFont
+            child._propagateParentLabelFont()
 
     @property
     def effectiveLabelFont(self):
         '''Font of the label text that should be used to draw the node'''
-        if self.__effectiveLabelFont:
-            return self.__effectiveLabelFont
+        if self.__labelFont:
+            return self.__labelFont
+        elif self.__parentLabelFont:
+            return self.__parentLabelFont
         else:
             return settings.get('defaultLabelFont')
 
-    def _propagateEffectiveLabelFont(self, font):
-        '''Set label font attribute to Node according inheritance policy'''
-        if equal(self.__effectiveLabelFont, font): return
-        if self.__labelFont:
-            self.__effectiveLabelFont = self.__labelFont
-        elif self.__parent:
-            self.__effectiveLabelFont = self.__parent.__effectiveLabelFont
-        else:
-            self.__effectiveLabelFont = font
-        if self.__effectiveLabelFont is not None:
-            self.__effectiveLabelFont = QFont(self.__effectiveLabelFont)
-        self.__labelFontMetrics = QFontMetricsF(self.effectiveLabelFont)
-        for child in self.__children:
-            child._propagateEffectiveLabelFont(self.__effectiveLabelFont)
-
     def _setEdgeColor(self, color):
         '''Set edge color attribute to Node'''
         self.__edgeColor = color
-        self._propagateEffectiveEdgeColor(color)
+        self._propagateParentEdgeColor()
+
+    def _propagateParentEdgeColor(self):
+        '''Set edge color attribute to Node according inheritance policy'''
+        if self.__edgeColor:
+            newParentEdgeColor = self.__edgeColor
+        else:
+            newParentEdgeColor = self.__parentEdgeColor
+        for child in self.__children:
+            if equal(child.__parentEdgeColor, newParentEdgeColor): continue
+            child.__parentEdgeColor = newParentEdgeColor
+            child._propagateParentEdgeColor()
 
     @property
     def effectiveEdgeColor(self):
         '''Edge color that should be used to draw the node'''
-        if self.__effectiveEdgeColor:
-            return self.__effectiveEdgeColor
+        if self.__edgeColor:
+            return self.__edgeColor
+        elif self.__parentEdgeColor:
+            return self.__parentEdgeColor
         else:
             return settings.get('defaultEdgeColor')
 
-    def _propagateEffectiveEdgeColor(self, color):
-        '''Set edge color attribute to Node according inheritance policy'''
-        if equal(self.__effectiveEdgeColor, color): return
-        if self.__edgeColor:
-            self.__effectiveEdgeColor = self.__edgeColor
-        elif self.__parent:
-            self.__effectiveEdgeColor = self.__parent.__effectiveEdgeColor
-        else:
-            self.__effectiveEdgeColor = color
-        if self.__effectiveEdgeColor is not None:
-            self.__effectiveEdgeColor = QColor(self.__effectiveEdgeColor)
-        for child in self.__children:
-            child._propagateEffectiveEdgeColor(self.__effectiveEdgeColor)
-
     def _setEdgeWidth(self, width):
         '''Set edge width attribute to Node'''
-        self.__edgeWidth = width if width else None
-        self._propagateEffectiveEdgeWidth(width)
+        self.__edgeWidth = width
+        self._propagateParentEdgeWidth()
+
+    def _propagateParentEdgeWidth(self):
+        '''Set edge width attribute to Node according inheritance policy'''
+        if self.__edgeWidth:
+            newParentEdgeWidth = self.__edgeWidth
+        else:
+            newParentEdgeWidth = self.__parentEdgeWidth
+        for child in self.__children:
+            if child.__parentEdgeWidth == newParentEdgeWidth: continue
+            child.__parentEdgeWidth = newParentEdgeWidth
+            child._propagateParentEdgeWidth()
 
     @property
     def effectiveEdgeWidth(self):
         '''Width of the node edge that should be used to draw the node'''
-        if self.__effectiveEdgeWidth:
-            edgeWidth = self.__effectiveEdgeWidth
+        if self.__edgeWidth:
+            edgeWidth = self.__edgeWidth
+        elif self.__parentEdgeWidth:
+            edgeWidth = self.__parentEdgeWidth
         else:
             edgeWidth = settings.get('defaultEdgeWidth')
         return float(edgeWidth % 10)
 
-    def _propagateEffectiveEdgeWidth(self, width):
-        '''Set edge width attribute to Node according inheritance policy'''
-        if self.__effectiveEdgeWidth == width: return
-        if self.__edgeWidth:
-            self.__effectiveEdgeWidth = self.__edgeWidth
-        elif self.__parent:
-            self.__effectiveEdgeWidth = self.__parent.__effectiveEdgeWidth
-        else:
-            self.__effectiveEdgeWidth = width
-        for child in self.__children:
-            child._propagateEffectiveEdgeWidth(self.__effectiveEdgeWidth)
-
     def _setEdgeStyle(self, style):
         '''Set edge style attribute to Node'''
-        self.__edgeStyle = style if style else None
-        self._propagateEffectiveEdgeStyle(style)
+        self.__edgeStyle = style
+        self._propagateParentEdgeStyle()
+
+    def _propagateParentEdgeStyle(self):
+        '''Set edge style attribute to Node according inheritance policy'''
+        if self.__edgeStyle:
+            newParentEdgeStyle = self.__edgeStyle
+        else:
+            newParentEdgeStyle = self.__parentEdgeStyle
+        for child in self.__children:
+            if child.__parentEdgeStyle == newParentEdgeStyle: continue
+            child.__parentEdgeStyle = newParentEdgeStyle
+            child._propagateParentEdgeStyle()
 
     @property
     def effectiveEdgeStyle(self):
         '''Edge style that should be used to draw the node'''
-        if self.__effectiveEdgeStyle:
-            return self.__effectiveEdgeStyle
+        if self.__edgeStyle:
+            return self.__edgeStyle
+        elif self.__parentEdgeStyle:
+            return self.__parentEdgeStyle
         else:
             return settings.get('defaultEdgeStyle')
 
-    def _propagateEffectiveEdgeStyle(self, style):
-        '''Set edge style attribute to Node according inheritance policy'''
-        if self.__effectiveEdgeStyle == style: return
-        if self.__edgeStyle:
-            self.__effectiveEdgeStyle = self.__edgeStyle
-        elif self.__parent:
-            self.__effectiveEdgeStyle = self.__parent.__effectiveEdgeStyle
-        else:
-            self.__effectiveEdgeStyle = style
-        for child in self.__children:
-            child._propagateEffectiveEdgeStyle(self.__effectiveEdgeStyle)
-
     def _setFont(self, font):
         '''Set font value of Node text'''
         self.__font = font
-        self._propagateEffectiveFont(font)
+        self._propagateParentFont()
+
+    def _determineFontToBePropagated(self):
+        '''Determine font that should be propagated to the child nodes'''
+        if self.__font and self.__propagateNodeFormatting:
+            return self.__font
+        return self.__parentFont
+
+    def _propagateParentFont(self):
+        '''Set font value of Node text according inheritance policy'''
+        self.__richcontent.setDefaultFont(self.effectiveFont)
+        self.__textFontMetrics = QFontMetricsF(self.effectiveFont)
+        self._updateTextWidth()
+        newParentFont = self._determineFontToBePropagated()
+        for child in self.__children:
+            if equal(child.__parentFont, newParentFont): continue
+            child.__parentFont = newParentFont
+            child._propagateParentFont()
 
     @property
     def effectiveFont(self):
         '''The font of the node text that should be used to draw the node'''
-        return self.__effectiveFont if self.__effectiveFont else settings.get('defaultFont')
-
-    def _propagateEffectiveFont(self, font):
-        '''Set font value of Node text according inheritance policy'''
-        if equal(self.__effectiveFont, font): return
         if self.__font:
-            self.__effectiveFont = self.__font
+            return self.__font
+        elif self.__parentFont:
+            return self.__parentFont
         else:
-            self.__effectiveFont = self.__parent.__effectiveFont if self.__parent else font
-        if self.__effectiveFont is not None:
-            self.__effectiveFont = QFont(self.__effectiveFont)
-        self.__richcontent.setDefaultFont(self.effectiveFont)
-        for child in self.__children:
-            child._propagateEffectiveFont(self.__effectiveFont)
+            return settings.get('defaultFont')
 
     def _setColor(self, color):
         '''Set color value of Node text content'''
         self.__color = color
-        self._propagateEffectiveColor(color)
+        self._propagateParentColor()
+
+    def _determineColorToBePropagated(self):
+        '''Determine the color that should be propagated to the child nodes'''
+        if self.__color and self.__propagateNodeFormatting:
+            return self.__color
+        return self.__parentColor
+
+    def _propagateParentColor(self):
+        '''Set color value of Node text content according inheritance policy'''
+        self.__colorPalette.setColor(QPalette.Text, self.effectiveColor)
+        newParentColor = self._determineColorToBePropagated()
+        for child in self.__children:
+            if equal(child.__parentColor, newParentColor): continue
+            child.__parentColor = newParentColor
+            child._propagateParentColor()
 
     @property
     def effectiveColor(self):
         '''The color of the node text that should be used to draw the node'''
-        if self.__effectiveColor:
-            return self.__effectiveColor
+        if self.__color:
+            return self.__color
+        elif self.__parentColor:
+            return self.__parentColor
         else:
             return settings.get('defaultNodeTextColor')
 
-    def _propagateEffectiveColor(self, color):
-        '''Set color value of Node text content according inheritance policy'''
-        if equal(self.__effectiveColor, color): return
-        if self.__color:
-            self.__effectiveColor = self.__color
-        elif self.__parent:
-            self.__effectiveColor = self.__parent.__effectiveColor
-        else:
-            self.__effectiveColor = color
-        if self.__effectiveColor is not None:
-            self.__effectiveColor = QColor(self.__effectiveColor)
-        self.__colorPalette.setColor(QPalette.Text, self.effectiveColor)
-        for child in self.__children:
-            child._propagateEffectiveColor(self.__effectiveColor)
-
-    def _setBgColor(self, color):
+    def _setBackgroundColor(self, color):
         '''Set background color value of Node'''
-        self.__background_color = color
-        self._propagateEffectiveBgColor(color)
+        self.__backgroundColor = color
+        self._propagateParentBackgroundColor()
+
+    def _determineBackgroundColorToBePropagated(self):
+        '''Determine the background color that should be propagated to the child nodes'''
+        if self.__backgroundColor and self.__propagateNodeFormatting:
+            return self.__backgroundColor
+        return self.__parentBackgroundColor
+
+    def _propagateParentBackgroundColor(self):
+        '''Set background color value of Node according inheritance policy'''
+        newParentBackgroundColor = self._determineBackgroundColorToBePropagated()
+        for child in self.__children:
+            if equal(child.__parentBackgroundColor, newParentBackgroundColor): continue
+            child.__parentBackgroundColor = newParentBackgroundColor
+            child._propagateParentBackgroundColor()
 
     @property
-    def effectiveBgColor(self):
+    def effectiveBackgroundColor(self):
         '''The background color of the node text that should be used to draw the node'''
-        if self.__effectiveBgColor:
-            return self.__effectiveBgColor
+        if self.__backgroundColor:
+            return self.__backgroundColor
+        elif self.__parentBackgroundColor:
+            return self.__parentBackgroundColor
         else:
             return settings.get('defaultNodeBackgroundColor')
 
-    def _propagateEffectiveBgColor(self, color):
-        '''Set background color value of Node according inheritance policy'''
-        if equal(self.__effectiveBgColor, color): return
-        if self.__background_color:
-            self.__effectiveBgColor = self.__background_color
-        elif self.__parent:
-            self.__effectiveBgColor = self.__parent.__effectiveBgColor
+    def _updateTextWidth(self):
+        '''Update text width'''
+        if self.__textFontMetrics.width(self.__richcontent.toPlainText()) < \
+                self.__maxWidth:
+            self.__richcontent.setTextWidth(-1)
         else:
-            self.__effectiveBgColor = color
-        if self.__effectiveBgColor is not None:
-            self.__effectiveBgColor = QColor(self.__effectiveBgColor)
-        for child in self.__children:
-            child._propagateEffectiveBgColor(self.__effectiveBgColor)
+            self.__richcontent.setTextWidth(self.__maxWidth)
 
     def updateProperties(self):
         '''Update cached properties of the node'''
         self.__richcontent.setDefaultFont(self.effectiveFont)
         self.__colorPalette.setColor(QPalette.Text, self.effectiveColor)
         self.__labelFontMetrics = QFontMetricsF(self.effectiveLabelFont)
+        self.__textFontMetrics = QFontMetricsF(self.effectiveFont)
+        self.__maxWidth = settings.get('maxNodeTextWidth')
+        self._updateTextWidth()
         for child in self.__children:
             child.updateProperties()
 
@@ -412,25 +448,21 @@ class Node(Element, Observable):
         # has similar name properties
         self.__parent = None
         self.__labelText = None
-        self.__labelFont = None
+        self.__labelFont = self.__parentLabelFont = None
         self.__labelFontMetrics = QFontMetricsF(settings.get('defaultLabelFont'))
-        self.__effectiveLabelFont = None
-        self.__labelColor = None
-        self.__effectiveLabelColor = None
+        self.__labelColor = self.__parentLabelColor = None
+        self.__propagateLabelFormatting = False
         self.__note = None
-        self.__effectiveStyle = None
         self.__left = None
-        self.__effectiveEdgeStyle = None
-        self.__edgeStyle = None
-        self.__effectiveEdgeColor = None
-        self.__edgeColor = None
-        self.__effectiveEdgeWidth = None
-        self.__edgeWidth = None
+        self.__edgeStyle = self.__parentEdgeStyle = None
+        self.__style = self.__parentStyle = None
+        self.__edgeColor = self.__parentEdgeColor = None
+        self.__edgeWidth = self.__parentEdgeWidth = None
         self.__cloud = None
-        self.__font = None
-        self.__effectiveFont = None
-        self.__effectiveColor = None
-        self.__effectiveBgColor = None
+        self.__font = self.__parentFont = None
+        self.__color = self.__parentColor = None
+        self.__backgroundColor = self.__parentBackgroundColor = None
+        self.__propagateNodeFormatting = False
         self.__icons = []
         self.__nodeAttribute = None
         self.__children = []
@@ -444,6 +476,8 @@ class Node(Element, Observable):
         self.__colorPalette.setColor(QPalette.Text, settings.get('defaultNodeTextColor'))
         self.__richcontent = QTextDocument()
         self.__richcontent.setDefaultFont(settings.get('defaultFont'))
+        self.__textFontMetrics = QFontMetricsF(settings.get('defaultFont'))
+        self.__maxWidth = settings.get('maxNodeTextWidth')
 
     def _setField(self, field, val):
         '''Create/set private field value'''
@@ -454,7 +488,12 @@ class Node(Element, Observable):
         return self.__dict__['_Node__' + fieldName]
 
     __LOCAL_ATTRIBUTES = set(('cloud', 'folded', 'icons', 'labelText', 'link'))
-    '''Properties which emit "localeAttributeChanged" notification and not has a setter'''
+    '''Properties which emit "localAttributeChanged" notification and not has a setter'''
+
+    __INHERITED_ATTRIBUTES = set(('font', 'color', 'backgroundColor', 'edgeWidth',
+            'edgeStyle', 'edgeColor', 'labelFont', 'labelColor', 'left', 'style',
+            'propagateNodeFormatting', 'propagateLabelFormatting'))
+    '''Node properties which emit "inheritedAttributeChanged" notification'''
 
     __NONEVENT_ATTRIBUTES = set(('created', 'id', 'modified', 'encrypted_content',
             'nodeAttribute', 'note', 'hgap', 'vgap', 'vshift'))
@@ -475,41 +514,15 @@ class Node(Element, Observable):
         '''
         maxNotifyLevel = -1 # -1 <=> no notification will be send
         for attrName, attrValue in attributes.items():
-            if attrName == 'font':
-                self._setFont(attrValue)
-                maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
-            elif attrName == 'color':
-                self._setColor(attrValue)
-                maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
-            elif attrName == 'background_color':
-                self._setBgColor(attrValue)
-                maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
-            elif attrName == 'text':
+            if attrName == 'text':
                 self._setPlainText(attrValue)
                 maxNotifyLevel = max(maxNotifyLevel, Node.__LOCAL_CHANGE_LEVEL)
             elif attrName == 'html':
                 self._setHtml(attrValue)
                 maxNotifyLevel = max(maxNotifyLevel, Node.__LOCAL_CHANGE_LEVEL)
-            elif attrName == 'edgeWidth':
-                self._setEdgeWidth(attrValue)
-                maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
-            elif attrName == 'edgeStyle':
-                self._setEdgeStyle(attrValue)
-                maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
-            elif attrName == 'edgeColor':
-                self._setEdgeColor(attrValue)
-                maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
-            elif attrName == 'labelFont':
-                self._setLabelFont(attrValue)
-                maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
-            elif attrName == 'labelColor':
-                self._setLabelColor(attrValue)
-                maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
-            elif attrName == 'left':
-                self._setLeft(attrValue)
-                maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
-            elif attrName == 'style':
-                self._setStyle(attrValue)
+            elif attrName in Node.__INHERITED_ATTRIBUTES:
+                setter = getattr(self, '_set%s%s' % (attrName[0].upper(), attrName[1:]))
+                setter(attrValue)
                 maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
             elif attrName in Node.__LOCAL_ATTRIBUTES:
                 self._setField(attrName, attrValue)
@@ -522,10 +535,10 @@ class Node(Element, Observable):
             self.notifyObservers(self, type = Node.__SIGNALS[maxNotifyLevel])
 
     WRITABLE_PROPERTIES = ('created', 'id', 'modified', 'encrypted_content', 'nodeAttribute',
-                             'note', 'icons', 'font', 'color', 'left', 'edgeColor',
-                             'edgeWidth', 'edgeStyle', 'link', 'hgap', 'vgap', 'vshift',
-                             'cloud', 'folded', 'background_color', 'style', 'text',
-                             'labelText', 'labelFont', 'labelColor')
+            'note', 'icons', 'font', 'color', 'left', 'edgeColor', 'edgeWidth', 'edgeStyle',
+            'link', 'hgap', 'vgap', 'vshift', 'cloud', 'folded', 'backgroundColor', 'style',
+            'text', 'labelText', 'labelFont', 'labelColor', 'propagateNodeFormatting',
+            'propagateLabelFormatting')
     '''Node writable properties that can be set with setAttributes() method'''
 
     def getAttributes(self, *propNames, **options):
@@ -577,6 +590,7 @@ class Node(Element, Observable):
         '''
         self.__isHtmlContent = False
         self.__richcontent.setPlainText(text)
+        self._updateTextWidth()
 
     def _setHtml(self, html):
         '''
@@ -584,6 +598,26 @@ class Node(Element, Observable):
         '''
         self.__isHtmlContent = True
         self.__richcontent.setHtml(html)
+        self._updateTextWidth()
+
+    def _setPropagateNodeFormatting(self, propagateFormatting):
+        '''
+        Set propagate formatting switch of the node text
+        @type propagateFormatting: bool
+        '''
+        self.__propagateNodeFormatting = propagateFormatting
+        self._propagateParentFont()
+        self._propagateParentColor()
+        self._propagateParentBackgroundColor()
+
+    def _setPropagateLabelFormatting(self, propagateFormatting):
+        '''
+        Set propagate formatting switch of the label text
+        @type propagateFormatting: bool
+        '''
+        self.__propagateLabelFormatting = propagateFormatting
+        self._propagateParentLabelColor()
+        self._propagateParentLabelFont()
 
     def addChild(self, child, position = None):
         '''
@@ -601,6 +635,16 @@ class Node(Element, Observable):
             self.__children.insert(position, child)
         else:
             self.__children.append(child)
+        self._propagateParentStyle()
+        self._propagateParentLabelColor()
+        self._propagateParentLabelFont()
+        self._propagateParentEdgeColor()
+        self._propagateParentEdgeWidth()
+        self._propagateParentEdgeStyle()
+        self._propagateParentFont()
+        self._propagateParentColor()
+        self._propagateParentBackgroundColor()
+        self.updateProperties()
         self.notifyObservers(child, type = 'childNodeAdded')
 
     def removeChild(self, child):
@@ -644,15 +688,15 @@ class Node(Element, Observable):
         else:
             dest.__children.insert(position, self)
         self._setLeft(self.left if dest.parent is None else dest.left)
-        self._propagateEffectiveStyle(dest.effectiveStyle)
-        self._propagateEffectiveEdgeColor(dest.effectiveEdgeColor)
-        self._propagateEffectiveEdgeStyle(dest.effectiveEdgeStyle)
-        self._propagateEffectiveEdgeWidth(dest.effectiveEdgeWidth)
-        self._propagateEffectiveLabelColor(dest.effectiveLabelColor)
-        self._propagateEffectiveLabelFont(dest.effectiveLabelFont)
-        self._propagateEffectiveColor(dest.effectiveColor)
-        self._propagateEffectiveBgColor(dest.effectiveBgColor)
-        self._propagateEffectiveFont(dest.effectiveFont)
+        dest._propagateParentStyle()
+        dest._propagateParentLabelColor()
+        dest._propagateParentLabelFont()
+        dest._propagateParentEdgeColor()
+        dest._propagateParentEdgeWidth()
+        dest._propagateParentEdgeStyle()
+        dest._propagateParentFont()
+        dest._propagateParentColor()
+        dest._propagateParentBackgroundColor()
         self.notifyObservers(self, dest, type = 'nodeMoved')
 
     def isAncestorOf(self, child):
@@ -698,15 +742,9 @@ class Node(Element, Observable):
         child.__parent = self
         # set inheritable attributes
         child.__left = self.__left
-        child.__effectiveStyle = self.__effectiveStyle
-        child.__effectiveEdgeColor = self.__effectiveEdgeColor
-        child.__effectiveEdgeWidth = self.__effectiveEdgeWidth
-        child.__effectiveEdgeStyle = self.__effectiveEdgeStyle
-        child.__effectiveLabelColor = self.__effectiveLabelColor
-        child.__effectiveBgColor = self.__effectiveBgColor
-        child._propagateEffectiveLabelFont(self.__effectiveLabelFont)
-        child._propagateEffectiveColor(self.__effectiveColor)
-        child._propagateEffectiveFont(self.__effectiveFont)
+        child.__parentFont = self._determineFontToBePropagated()
+        child.__parentColor = self._determineColorToBePropagated()
+        child.__parentBackgroundColor = self._determineBackgroundColorToBePropagated()
         return child
 
     @property
@@ -739,7 +777,6 @@ class Node(Element, Observable):
         '''
         painter.save()
         paintContext = QAbstractTextDocumentLayout.PaintContext()
-#        painter.setFont(self.effectiveFont)
         paintContext.palette = self.__colorPalette
         self.__richcontent.documentLayout().draw(painter, paintContext)
         painter.restore()
