@@ -24,9 +24,14 @@
 Dialogs for Desktop platform
 '''
 
-from PySide.QtGui import *
-from PySide.QtCore import *
-from hivemind.dialogs import *
+from PySide.QtGui import QToolBar, QIcon, QTabWidget, QGridLayout, \
+QHBoxLayout, QPalette, QTextBrowser, QFrame, QLabel, QDialogButtonBox, \
+QVBoxLayout, QGroupBox, QWidget
+from PySide.QtCore import SIGNAL, QSize, Qt
+from hivemind.dialogs import EditNodeDialog, EditLabelDialog, IconDialog, \
+AboutDialog, EditEdgeDialog, SettingsDialog, NetworkConnectionDialog, \
+AffiliationDialog, SettingsCreator, NetworkServiceDialog, NetworkClientDialog
+from hivemind.attribute import adaptCallable
 import hivemind.__version__ as __version__
 
 
@@ -77,8 +82,12 @@ class DesktopEditNodeDialog(EditNodeDialog):
         gridLayout = QGridLayout(self)
         gridLayout.addWidget(self._fontToolbar, 0, 0, 1, 2)
         gridLayout.addWidget(toolbar, 0, 2, 1, 2)
-        gridLayout.addWidget(self.__tabWidget, 1, 0, 4, 4)
-        gridLayout.addWidget(self._buttonBox, 5, 0, 1, 4)
+        gridLayout.addWidget(self.__tabWidget, 1, 0, 1, 4)
+        lastLineLayout = QHBoxLayout()
+        lastLineLayout.addWidget(self._propagateFormatting)
+        lastLineLayout.addStretch()
+        lastLineLayout.addWidget(self._buttonBox)
+        gridLayout.addLayout(lastLineLayout, 2, 0, 1, 4)
         QWidget.setTabOrder(self._editor, self.__tabWidget)
         self._textHtmlAction.connect(SIGNAL('toggled(bool)'),
                 adaptCallable(self._enableSourceTab))
@@ -148,7 +157,11 @@ class DesktopEditLabelDialog(EditLabelDialog):
         mainLayout.addWidget(self._comboSize, 0, 7, 1, 3)
         mainLayout.addWidget(self._editor, 1, 0, 1, 10)
         mainLayout.addLayout(secondaryLayout, 2, 0, 1, 10)
-        mainLayout.addWidget(self._buttonBox, 3, 0, 1, 10)
+        bottomLayout = QHBoxLayout()
+        bottomLayout.addWidget(self._propagateFormatting)
+        bottomLayout.addStretch()
+        bottomLayout.addWidget(self._buttonBox)
+        mainLayout.addLayout(bottomLayout, 3, 0, 1, 10)
         self.setLayout(mainLayout)
         QWidget.setTabOrder(self._editor, self._buttonBox)
         QWidget.setTabOrder(self._buttonBox, self._comboFont)
@@ -305,32 +318,21 @@ class DesktopEditEdgeDialog(EditEdgeDialog):
 
     def _initComponents(self):
         '''Form initialization'''
-        widthLayout = QHBoxLayout()
-        widthLayout.addWidget(self._widthParent)
-        widthLayout.addWidget(self._widthThin)
-        widthLayout.addWidget(self._widthOne)
-        widthLayout.addWidget(self._widthTwo)
-        widthLayout.addWidget(self._widthFour)
-        widthLayout.addWidget(self._widthEight)
-        styleLayout = QHBoxLayout()
-        styleLayout.addWidget(self._styleParent)
-        styleLayout.addWidget(self._styleLinear)
-        styleLayout.addWidget(self._styleBezier)
-        styleLayout.addWidget(self._styleSharpLinear)
-        styleLayout.addWidget(self._styleSharpBezier)
         colorLayout = QHBoxLayout()
         colorLayout.addWidget(self._colorParent)
         colorLayout.addWidget(self._colorButton)
         mainLayout = QGridLayout()
         mainLayout.addWidget(self._widthLabel, 0, 0)
-        mainLayout.addLayout(widthLayout, 1, 0)
-        mainLayout.addWidget(self._styleLabel, 2, 0)
-        mainLayout.addLayout(styleLayout, 3, 0)
-        mainLayout.addWidget(self._colorLabel, 4, 0)
-        mainLayout.addLayout(colorLayout, 5, 0)
-        mainLayout.addWidget(self._buttonBox, 6, 0,)
+        mainLayout.addWidget(self._styleLabel, 0, 1)
+        mainLayout.addWidget(self._edgeWidthComboBox, 1, 0)
+        mainLayout.addWidget(self._edgeStyleComboBox, 1, 1)
+        mainLayout.addWidget(self._nodeStyleLabel, 2, 0, 1, 2)
+        mainLayout.addWidget(self._nodeStyleComboBox, 3, 0, 1, 2)
+        mainLayout.addLayout(colorLayout, 4, 0, 1, 2)
+        mainLayout.addWidget(self._buttonBox, 5, 0, 1, 2)
         self.setLayout(mainLayout)
 
+
 class DesktopSettingsDialog(SettingsDialog):
     '''
     Settings dialog for Desktop platform
@@ -341,11 +343,12 @@ class DesktopSettingsDialog(SettingsDialog):
         @type parent: QWidget
         '''
         SettingsDialog.__init__(self, parent)
-        self._general = SettingsCreator(['locale', 'confirmDelete'])
+        self._general = SettingsCreator(['locale', 'defaultZoomLevel', 'confirmDelete'])
         generalGroup = QGroupBox(self.tr('General settings'))
         generalGroup.setLayout(self._general.getLayout())
         self._node = SettingsCreator(['defaultFont', 'defaultNodeTextColor',
-                'defaultNodeBackgroundColor', 'defaultSelectedNodeBackgroundColor'])
+                'defaultNodeBackgroundColor', 'defaultSelectedNodeBackgroundColor',
+                'maxNodeTextWidth'])
         nodeGroup = QGroupBox(self.tr('Node settings'))
         nodeGroup.setLayout(self._node.getLayout())
         self._edge = SettingsCreator(['defaultLabelFont', 'defaultLabelColor',
@@ -374,19 +377,40 @@ class DesktopSettingsDialog(SettingsDialog):
         SettingsDialog._accept(self)
 
 
-class DesktopNetworkConnectionDialog(NetworkConnectionDialog):
-    '''
-    Network connection dialog for Desktop platform
-    @author: Oleg Kandaurov
-    '''
-    def __init__(self, credentials, client, parent = None):
-        NetworkConnectionDialog.__init__(self, credentials, client, parent)
-
-
 class DesktopAffiliationDialog(AffiliationDialog):
     '''
     Affiliation dialog for Desktop platform
     @author: Oleg Kandaurov
     '''
+    def __init__(self, model, parent = None):
+        AffiliationDialog.__init__(self, model, parent)
+
+
+class DesktopNetworkServiceDialog(NetworkServiceDialog):
+    '''
+    Service dialog for Desktop platfrom
+    @author: Oleg Kandaurov
+    '''
+
     def __init__(self, parent = None):
-        AffiliationDialog.__init__(self, parent)
+        NetworkServiceDialog.__init__(self, parent)
+
+
+class DesktopNetworkClientDialog(NetworkClientDialog):
+    '''
+    Client dialog for Desktop platfrom
+    @author: Oleg Kandaurov
+    '''
+
+    def __init__(self, rosterModel, parent = None):
+        NetworkClientDialog.__init__(self, rosterModel, parent)
+
+
+class DesktopNetworkConnectionDialog(NetworkConnectionDialog):
+    '''
+    Connection dialog for Desktop platfrom
+    @author: Oleg Kandaurov
+    '''
+
+    def __init__(self, parent = None):
+        NetworkConnectionDialog.__init__(self, parent)
