@@ -27,10 +27,21 @@ Abstract dialog classes
 
 import hivemind.settings as settings
 import hivemind.resource as resource
-from PySide.QtGui import *
-from PySide.QtCore import *
-from hivemind.attribute import *
-from hivemind.gui_widgets import *
+from PySide.QtGui import QDialog, QMessageBox, QDialogButtonBox, QLabel, QLineEdit, \
+QVBoxLayout, QFormLayout, QAbstractItemView, QTableView, QHeaderView, QHBoxLayout, \
+QRadioButton, QButtonGroup, QComboBox, QPushButton, QToolBar, QFontComboBox, QAction, \
+QFontDatabase, QColorDialog, QTextCharFormat, QFont, QPalette, QBrush, QTextCursor, \
+QGridLayout, QCheckBox, QGraphicsView
+from PySide.QtCore import SIGNAL, QRegExp, Qt, QSize, SLOT
+from hivemind.attribute import readable, adaptCallable
+from hivemind.gui_widgets import SearchingTrMixin, SpecialTextEdit, \
+ScalingWidget, IconList, IconTable, LineEditBinder, CheckBoxBinder, \
+SettingsCreator
+from hivemind.network.network_models import AffiliationDelegate
+from twisted.words.protocols.jabber import jid
+
+'''Regexp for jid validation'''
+VALID_JID = '[A-Za-z0-9._%+-]+@(?:[A-Za-z0-9-]+\\.)+[A-Za-z]{2,6}'
 
 class CommonDialog(SearchingTrMixin, QDialog):
     '''
@@ -70,9 +81,7 @@ class EditNodeDialog(CommonDialog):
         CommonDialog.__init__(self, parent)
         self.setWindowTitle(self.tr('Node editor'))
         self.__node = node
-        self.__background = None
-        self.__font = None
-        self.__color = None
+        self.__background = self.__font = self.__color = None
         self._isHtml = self.__node.isHtml()
         self.__newAttributes = None
         self._isHtmlSourceMode = False
@@ -111,6 +120,8 @@ class EditNodeDialog(CommonDialog):
         # color actions
         self._colorAction = QAction(self)
         self._backgroundAction = QAction(self)
+        # adhoc formatting propagation checkbox
+        self._propagateFormatting = QCheckBox(self.tr('Propagate formatting to child nodes'))
         # clear format action
         self._clearFormatAction = QAction(self)
         # actions signals connection
@@ -168,7 +179,8 @@ class EditNodeDialog(CommonDialog):
             storeAttrs['font'] = self.__font
             storeAttrs['text'] = self._editor.toPlainText()
         storeAttrs['color'] = self.__color
-        storeAttrs['background_color'] = self.__background
+        storeAttrs['backgroundColor'] = self.__background
+        storeAttrs['propagateNodeFormatting'] = self._propagateFormatting.isChecked()
         self.__newAttributes = storeAttrs
         QDialog.accept(self)
 
@@ -183,6 +195,7 @@ class EditNodeDialog(CommonDialog):
     def _initEditor(self):
         '''Initialize text editor'''
         self._textHtmlAction.setChecked(self._isHtml)
+        self._propagateFormatting.setChecked(self.__node.propagateNodeFormatting)
         if self.__node.isHtml():
             self._editor.setHtml(self.__node.text)
             self.__color = self.__font = None
@@ -192,7 +205,7 @@ class EditNodeDialog(CommonDialog):
             self._setColor(self.__node.color)
         self._editor.document().setDefaultFont(settings.get('defaultFont'))
         self._fontChanged(self._editor.textCursor().charFormat().font())
-        self._setBackgroundColor(self.__node.background_color)
+        self._setBackgroundColor(self.__node.backgroundColor)
         self._editor.selectAll()
 
     def _setHtmlSourceMode(self, isHtmlSourceMode):
@@ -441,6 +454,7 @@ class EditLabelDialog(CommonDialog):
         self._colorParent = QCheckBox(self.tr("Parent's color"))
         self._colorButton = QPushButton(self.tr('Choose color'))
         self._fontParent = QCheckBox(self.tr("Parent's font"))
+        self._propagateFormatting = QCheckBox(self.tr('Propagate formatting to child nodes'))
         self._boldAction.connect(SIGNAL('triggered(bool)'), self._setBold)
         self._italicAction.connect(SIGNAL('triggered(bool)'), self._setItalic)
         self._underlineAction.connect(SIGNAL('triggered(bool)'), self._setUnderline)
@@ -475,6 +489,7 @@ class EditLabelDialog(CommonDialog):
         self._comboSize.setEditable(True)
         font = self.__node.effectiveLabelFont
         self._comboFont.setCurrentFont(font)
+        self._propagateFormatting.setChecked(self.__node.propagateLabelFormatting)
         self._editor.selectAll()
 
     def _fontSizes(self, font):
@@ -652,6 +667,7 @@ class EditLabelDialog(CommonDialog):
         modified['labelColor'] = self.__color
         modified['labelFont'] = self.__font
         modified['labelText'] = self._editor.toPlainText().replace('\n', ' ')
+        modified['propagateLabelFormatting'] = self._propagateFormatting.isChecked()
         self.__newAttributes = modified
         QDialog.accept(self)
 
@@ -766,33 +782,28 @@ class EditEdgeDialog(CommonDialog):
         '''Create components'''
         #pylint: disable = W0201
         # Setting up width view
-        self._widthLabel = QLabel(self.tr('Width'))
-        self._widthParent = QRadioButton(self.tr('Parent'))
-        self._widthThin = QRadioButton(self.tr('Thin'))
-        self._widthOne = QRadioButton('1')
-        self._widthTwo = QRadioButton('2')
-        self._widthFour = QRadioButton('4')
-        self._widthEight = QRadioButton('8')
-        widthGroup = QButtonGroup(self)
-        widthGroup.addButton(self._widthParent)
-        widthGroup.addButton(self._widthThin)
-        widthGroup.addButton(self._widthOne)
-        widthGroup.addButton(self._widthTwo)
-        widthGroup.addButton(self._widthFour)
-        widthGroup.addButton(self._widthEight)
+        self._widthLabel = QLabel(self.tr('Edge width'))
+        self._edgeWidthComboBox = QComboBox()
+        self._edgeWidthComboBox.addItem(self.tr('Parent'), None)
+        self._edgeWidthComboBox.addItem(self.tr('Thin'), 11)
+        self._edgeWidthComboBox.addItem('1', 1)
+        self._edgeWidthComboBox.addItem('2', 2)
+        self._edgeWidthComboBox.addItem('4', 4)
+        self._edgeWidthComboBox.addItem('8', 8)
         # Setting up style view
-        self._styleLabel = QLabel(self.tr('Style'))
-        self._styleParent = QRadioButton(self.tr('Parent'))
-        self._styleLinear = QRadioButton(self.tr('Linear'))
-        self._styleBezier = QRadioButton(self.tr('Bezier'))
-        self._styleSharpLinear = QRadioButton(self.tr('Sharp linear'))
-        self._styleSharpBezier = QRadioButton(self.tr('Sharp bezier'))
-        styleGroup = QButtonGroup(self)
-        styleGroup.addButton(self._styleParent)
-        styleGroup.addButton(self._styleLinear)
-        styleGroup.addButton(self._styleBezier)
-        styleGroup.addButton(self._styleSharpLinear)
-        styleGroup.addButton(self._styleSharpBezier)
+        self._styleLabel = QLabel(self.tr('Edge style'))
+        self._edgeStyleComboBox = QComboBox()
+        self._edgeStyleComboBox.addItem(self.tr('Parent'), None)
+        self._edgeStyleComboBox.addItem(self.tr('Linear'), 'linear')
+        self._edgeStyleComboBox.addItem(self.tr('Bezier'), 'bezier')
+        self._edgeStyleComboBox.addItem(self.tr('Sharp linear'), 'sharp_linear')
+        self._edgeStyleComboBox.addItem(self.tr('Sharp bezier'), 'sharp_bezier')
+        # Setting up node style view
+        self._nodeStyleLabel = QLabel(self.tr('Node style'))
+        self._nodeStyleComboBox = QComboBox()
+        self._nodeStyleComboBox.addItem(self.tr('Parent'), None)
+        self._nodeStyleComboBox.addItem(self.tr('Bubble'), 'bubble')
+        self._nodeStyleComboBox.addItem(self.tr('Fork'), 'fork')
         # Setting up color view
         self._colorLabel = QLabel(self.tr('Color'))
         self._colorParent = QCheckBox(self.tr('Parent'))
@@ -807,19 +818,12 @@ class EditEdgeDialog(CommonDialog):
         self.__color = self.__node.edgeColor
         if self.__color is None:
             self._colorParent.setChecked(True)
-        # Initialize width of the Edge
-        self.__widthToButton = {1 : self._widthOne, 2 : self._widthTwo,
-                         4 : self._widthFour, 8: self._widthEight,
-                         11 : self._widthThin,
-                         None : self._widthParent}
-        self.__widthToButton[self.__node.edgeWidth].setChecked(True)
-        # Initialize style of the Edge
-        self.__styleToButton = {'linear' : self._styleLinear,
-                          'bezier' : self._styleBezier,
-                          'sharp_linear' : self._styleSharpLinear,
-                          'sharp_bezier' : self._styleSharpBezier,
-                          None : self._styleParent}
-        self.__styleToButton[self.__node.edgeStyle].setChecked(True)
+        self._edgeWidthComboBox.setCurrentIndex(self._edgeWidthComboBox.findData(
+                self.__node.edgeWidth))
+        self._edgeStyleComboBox.setCurrentIndex(self._edgeStyleComboBox.findData(
+                self.__node.edgeStyle))
+        self._nodeStyleComboBox.setCurrentIndex(self._nodeStyleComboBox.findData(
+                self.__node.style))
 
     def _edgeColor(self):
         '''Choose color of the Edge'''
@@ -838,12 +842,12 @@ class EditEdgeDialog(CommonDialog):
         elif self.__color is None:
             self.__color = self.__node.effectiveEdgeColor
         modified['edgeColor'] = self.__color
-        for width, button in self.__widthToButton.iteritems():
-            if button.isChecked():
-                modified['edgeWidth'] = width
-        for style, button in self.__styleToButton.iteritems():
-            if button.isChecked():
-                modified['edgeStyle'] = style
+        modified['edgeWidth'] = self._edgeWidthComboBox.itemData(
+                self._edgeWidthComboBox.currentIndex())
+        modified['edgeStyle'] = self._edgeStyleComboBox.itemData(
+                self._edgeStyleComboBox.currentIndex())
+        modified['style'] = self._nodeStyleComboBox.itemData(
+                self._nodeStyleComboBox.currentIndex())
         self.__newAttributes = modified
         QDialog.accept(self)
 
@@ -884,83 +888,6 @@ class SettingsDialog(CommonDialog):
                     of the application!'))
         QDialog.accept(self)
 
-class NetworkConnectionDialog(CommonDialog):
-    '''
-    Abstract class for network connection dialog
-    @author: Oleg Kandaurov
-    '''
-    def __init__(self, credentials, client, parent = None):
-        '''
-        @param credentials: Show XMPP credentials
-        @type credentials: bool
-        @param client: Show client or server dialogs
-        @type client: bool
-        @type parent: QWidget
-        '''
-        CommonDialog.__init__(self, parent)
-        self.__credentials = credentials
-        self.__client = client
-        self.setWindowTitle(self.tr('Network Connection'))
-        self._createComponents()
-        self._initComponents()
-
-    def _createComponents(self):
-        '''Create Components'''
-        #pylint: disable = W0201
-        self.__newAttributes = dict()
-        mailRegexp = QRegExp('[A-Za-z0-9._%+-]+@(?:[A-Za-z0-9-]+\\.)+[A-Za-z]{2,6}')
-        self._userBinder = LineEditBinder('userJid', settings.get('userJid'), mailRegexp)
-        self._userLabel = QLabel(self.tr('User JID:'))
-        self._passwordBinder = LineEditBinder('password', '')
-        self._passwordBinder.setEchoMode(QLineEdit.Password)
-        self._passwordLabel = QLabel(self.tr('Password:'))
-        self._serviceBinder = LineEditBinder('serviceJid', settings.get('serviceJid'),
-                mailRegexp)
-        self._serviceLabel = QLabel(self.tr('Service JID:'))
-        self._readOnlyBinder = CheckBoxBinder('readOnly', settings.get('readOnly'))
-        self._readOnlyBinder.setText(self.tr('Read only'))
-
-    def _initComponents(self):
-        '''Init components'''
-        mainLayout = QVBoxLayout()
-        formLayout = QFormLayout()
-        if self.__credentials:
-            formLayout.addRow(self._userLabel, self._userBinder)
-            formLayout.addRow(self._passwordLabel, self._passwordBinder)
-        if self.__client == True:
-            formLayout.addRow(self._serviceLabel, self._serviceBinder)
-        elif self.__client == False:
-            formLayout.addRow(self._readOnlyBinder)
-        mainLayout.addLayout(formLayout)
-        mainLayout.addWidget(self._buttonBox)
-        self.setLayout(mainLayout)
-
-    def _accept(self):
-        '''Hide the dialog, update attributes'''
-        if not self._serviceBinder.isValid() and self.__client or \
-        not self._userBinder.isValid():
-            QMessageBox.critical(self, self.tr('Incorrect JID!'),
-                    self.tr('Please, enter correct jabber id.'))
-            return
-        if self.__credentials:
-            self.__newAttributes['userJid'] = self._userBinder.retrieve().values().pop()
-        if self.__client:
-            self.__newAttributes['serviceJid'] = self._serviceBinder.retrieve().values().pop()
-        else:
-            self.__newAttributes['readOnly'] = self._readOnlyBinder.retrieve().values().pop()
-        settings.set(**self.__newAttributes)
-        if self.__credentials:
-            self.__newAttributes['password'] = self._passwordBinder.retrieve().values().pop()
-        QDialog.accept(self)
-
-    def attributes(self):
-        '''
-        Get dict of modified attributes with new values
-        @return: new attribute values
-        @rtype: dict
-        '''
-        return self.__newAttributes
-
 
 class SideSelectionDialog(CommonDialog):
     '''
@@ -1018,42 +945,36 @@ class AffiliationDialog(CommonDialog):
     @author: Oleg Kandaurov
     '''
 
-    def __init__(self, parent = None):
+    def __init__(self, model, parent = None):
+        '''Constructor'''
         CommonDialog.__init__(self, parent)
+        self.__model = model
         self.setWindowTitle(self.tr('Edit affiliations'))
-        self.__supportedStatuses = {'subscribed': self.tr('Subscribed'),
-                'unsubscribed': self.tr('Unsubscribed')}
         self._createComponents()
         self._initComponents()
 
     def _createComponents(self):
-        '''
-        Create components
-        '''
+        '''Create components'''
         #pylint: disable = W0201
-        self.__model = QStandardItemModel(0, 3)
         self.__delegate = AffiliationDelegate()
         self.__view = QTableView()
-        self.__model.setHorizontalHeaderLabels([self.tr('JID'),
-                self.tr('Affiliation'), self.tr('Status')])
         self.__view.setModel(self.__model)
+        self.__view.setItemDelegateForColumn(1, self.__delegate)
+        self.__view.setEditTriggers(QAbstractItemView.AllEditTriggers)
         horizontalHeader = self.__view.horizontalHeader()
         horizontalHeader.setResizeMode(QHeaderView.Stretch)
         horizontalHeader.setStretchLastSection(True)
-        self.__view.setItemDelegateForColumn(1, self.__delegate)
         self.__jidLabel = QLabel(self.tr('JID'))
         self.__jidEdit = QLineEdit()
         self.__affiliationLabel = QLabel(self.tr('Affiliation'))
         self.__affiliationCombo = QComboBox()
-        for data, name in self.__delegate.supportedAffiliations.iteritems():
+        for data, name in self.__model.mapAffiliations.iteritems():
             self.__affiliationCombo.addItem(name, data)
         self.__additionButton = QPushButton(self.tr('Add participant'))
         self.__additionButton.clicked.connect(self._addParticipant)
 
     def _initComponents(self):
-        '''
-        Initialize components
-        '''
+        '''Initialize components'''
         jidLayout = QVBoxLayout()
         self.__jidLabel.setAlignment(Qt.AlignCenter)
         jidLayout.addWidget(self.__jidLabel)
@@ -1077,68 +998,237 @@ class AffiliationDialog(CommonDialog):
         self.setLayout(mainLayout)
 
     def _addParticipant(self):
-        '''
-        Retrieve info from components and create participant with given access
-        '''
-        jidRegexp = QRegExp('[A-Za-z0-9._%+-]+@(?:[A-Za-z0-9-]+\\.)+[A-Za-z]{2,6}')
+        '''Retrieve info from components and create participant with given access'''
+        jidRegexp = QRegExp(VALID_JID)
         if not jidRegexp.exactMatch(self.__jidEdit.text()):
             QMessageBox.critical(self, self.tr('Incorrect JID!'),
                     self.tr('Please, enter correct jabber id.'))
             return
-        self.setAffiliation(self.__jidEdit.text(),
+        self.__model.setAffiliation(jid.internJID(self.__jidEdit.text()),
                 self.__affiliationCombo.itemData(self.__affiliationCombo.currentIndex()))
         self.__jidEdit.clear()
 
-    def updateStatus(self, event, subscriber):
-        '''
-        Update status of widgets according to received event
-        @param event: Type of event
-        @type event: str
-        @param subscriber: Subcriber that generates event
-        @type subscriber: str
-        '''
-        for row in range(0, self.__model.rowCount()):
-            if self.__model.index(row, 0).data() == subscriber:
-                self.__model.setData(self.__model.index(row, 2),
-                        self.__supportedStatuses[event])
-
-    def setAffiliation(self, jid, newAffiliation):
-        '''
-        Set new affiliation
-        @param jid: jid to set affiliation
-        @type jid: str
-        @param affiliation: Affiliation for jid
-        @type affiliation: str
-        '''
-        for row in range(0, self.__model.rowCount()):
-            if self.__model.index(row, 0).data() == jid:
-                self.__model.setData(self.__model.index(row, 1),
-                        newAffiliation)
-                return
-        self.__model.setRowCount(self.__model.rowCount() + 1)
-        self.__model.setData(self.__model.index(self.__model.rowCount() - 1, 2),
-                self.__supportedStatuses['subscribed'])
-        self.__model.setData(self.__model.index(self.__model.rowCount() - 1, 1),
-                newAffiliation)
-        self.__model.setData(self.__model.index(self.__model.rowCount() - 1, 0),
-                jid)
-        self.__model.item(self.__model.rowCount() - 1, 0).setEditable(False)
-        self.__model.item(self.__model.rowCount() - 1, 2).setEditable(False)
-
-    def getAffiliations(self):
-        '''
-        Extract affiliations from model
-        @return: Dictionary of jid and affiliation
-        @rtype: dict
-        '''
-        affiliations = {}
-        for row in range(0, self.__model.rowCount()):
-            affiliations[self.__model.index(row, 0).data()] = \
-                    self.__model.index(row, 1).data()
-        return affiliations
-
     def _accept(self):
         '''
         Hide the dialog
         '''
         QDialog.accept(self)
+
+
+class NetworkAuthorizationDialog(QMessageBox):
+    '''
+    Authorization dialog
+    @author: Oleg Kandaurov
+    '''
+
+    readable('mapButton')
+    def __init__(self, requestor, parent = None):
+        '''
+        @type parent: QWidget
+        @type requestor: str
+        '''
+        QMessageBox.__init__(self, parent)
+        self.setIcon(QMessageBox.Question)
+        self.setWindowTitle(self.tr('Authorization request'))
+        self.setText(self.tr('Authorization request from %s') % requestor)
+        self.setInformativeText(self.tr('Do you want to accept authorization request?'))
+        acceptButton = self.addButton(self.tr('Accept'), QMessageBox.AcceptRole)
+        denyButton = self.addButton(self.tr('Deny'), QMessageBox.RejectRole)
+        blockButton = self.addButton(self.tr('Block'), QMessageBox.ActionRole)
+        self.setDefaultButton(acceptButton)
+        self.setEscapeButton(denyButton)
+        self.__mapButton = {acceptButton: 'accept', denyButton: 'deny', blockButton: 'block'}
+
+
+class NetworkServiceDialog(CommonDialog):
+    '''
+    Abstract class for service dialog
+    @author: Oleg Kandaurov
+    '''
+    readable('attributes')
+    def __init__(self, parent = None):
+        CommonDialog.__init__(self, parent)
+        self.setWindowTitle(self.tr('Create service'))
+        self.__attributes = dict()
+        self._createComponents()
+        self._initComponents()
+
+    def _createComponents(self):
+        '''Create components'''
+        #pylint: disable = W0201
+        self.__openModelRadio = QRadioButton(self.tr('Open'))
+        self.__authModelRadio = QRadioButton(self.tr('Authorize'))
+        self.__rosterModelRadio = QRadioButton(self.tr('Roster'))
+        self.__whitelistModelRadio = QRadioButton(self.tr('Whitelist'))
+        self.__accessModelGroup = QButtonGroup()
+        self.__accessModelGroup.addButton(self.__openModelRadio)
+        self.__accessModelGroup.addButton(self.__rosterModelRadio)
+        self.__accessModelGroup.addButton(self.__authModelRadio)
+        self.__accessModelGroup.addButton(self.__whitelistModelRadio)
+        self.__mapAccessModels = {'open': self.__openModelRadio,
+                'roster': self.__rosterModelRadio, 'authorize': self.__authModelRadio,
+                'whitelist': self.__whitelistModelRadio}
+        self.__mapAccessModels[settings.get('accessModel')].setChecked(True)
+        self.__readOnlyBinder = CheckBoxBinder('readOnly', settings.get('readOnly'))
+        self.__readOnlyBinder.setText(self.tr('Read only'))
+
+    def _initComponents(self):
+        '''Create components'''
+        mainLayout = QVBoxLayout()
+        firstGroupLayout = QHBoxLayout()
+        firstGroupLayout.addWidget(self.__openModelRadio)
+        firstGroupLayout.addWidget(self.__rosterModelRadio)
+        secondGroupLayout = QHBoxLayout()
+        secondGroupLayout.addWidget(self.__authModelRadio)
+        secondGroupLayout.addWidget(self.__whitelistModelRadio)
+        mainLayout.addLayout(firstGroupLayout)
+        mainLayout.addLayout(secondGroupLayout)
+        mainLayout.addWidget(self.__readOnlyBinder)
+        mainLayout.addWidget(self._buttonBox)
+        self.setLayout(mainLayout)
+
+    def _accept(self):
+        '''Hide the dialog, update attributes'''
+        self.__attributes = self.__readOnlyBinder.retrieve()
+        for model, button in self.__mapAccessModels.iteritems():
+            if button.isChecked():
+                self.__attributes['accessModel'] = model
+        settings.set(**self.__attributes)
+        QDialog.accept(self)
+
+
+class NetworkClientDialog(CommonDialog):
+    '''
+    Abstract class for client dialog
+    @author: Oleg Kandaurov
+    '''
+
+    readable('attributes')
+    def __init__(self, rosterModel, parent = None):
+        CommonDialog.__init__(self, parent)
+        self.setWindowTitle(self.tr('Create client'))
+        self.__model = rosterModel
+        self.__attributes = dict()
+        self._createComponents()
+        self._initComponents()
+
+    def _createComponents(self):
+        '''Create components'''
+        #pylint: disable = W0201
+        self.__view = QTableView()
+        horizontalHeader = self.__view.horizontalHeader()
+        horizontalHeader.setResizeMode(QHeaderView.Stretch)
+        horizontalHeader.setStretchLastSection(True)
+        self.__view.setModel(self.__model)
+        self.__serviceBinder = LineEditBinder('serviceJid', settings.get('serviceJid'),
+                QRegExp(VALID_JID))
+        self.__serviceLabel = QLabel(self.tr('Service JID:'))
+        self.__view.clicked.connect(self._itemClicked)
+
+    def _initComponents(self):
+        '''Create components'''
+        mainLayout = QVBoxLayout()
+        firstLayout = QHBoxLayout()
+        firstLayout.addWidget(self.__serviceLabel)
+        firstLayout.addWidget(self.__serviceBinder)
+        mainLayout.addLayout(firstLayout)
+        mainLayout.addWidget(self.__view)
+        mainLayout.addWidget(self._buttonBox)
+        self.setLayout(mainLayout)
+
+    def _itemClicked(self, modelIndex):
+        '''Process clicked signal from view'''
+        self.__serviceBinder.setText(modelIndex.data(Qt.EditRole))
+
+    def _accept(self):
+        '''Hide the dialog, update attributes'''
+        if not self.__serviceBinder.isValid():
+            QMessageBox.critical(self, self.tr('Incorrect JID!'),
+                    self.tr('Please, enter correct jabber id.'))
+            return
+        self.__attributes = self.__serviceBinder.retrieve()
+        settings.set(**self.__attributes)
+        QDialog.accept(self)
+
+
+class NetworkConnectionDialog(CommonDialog):
+    '''
+    Abstract class for connection dialog
+    @author: Oleg Kandaurov
+    '''
+
+    readable('attributes')
+    def __init__(self, parent = None):
+        CommonDialog.__init__(self, parent)
+        self.setWindowTitle(self.tr('Connect to XMPP'))
+        self.__attributes = dict()
+        self._createComponents()
+        self._initComponents()
+
+    def _createComponents(self):
+        '''Create components'''
+        #pylint: disable = W0201
+        self.__userBinder = LineEditBinder('userJid', settings.get('userJid'),
+                QRegExp(VALID_JID))
+        self.__userLabel = QLabel(self.tr('User JID:'))
+        self.__passwordEdit = QLineEdit()
+        self.__passwordEdit.setEchoMode(QLineEdit.Password)
+        password = settings.get('password')
+        if password is not None:
+            self.__passwordEdit.setText(password)
+        self.__passwordLabel = QLabel(self.tr('Password:'))
+
+    def _initComponents(self):
+        '''Create components'''
+        mainLayout = QVBoxLayout()
+        formLayout = QFormLayout()
+        formLayout.addRow(self.__userLabel, self.__userBinder)
+        formLayout.addRow(self.__passwordLabel, self.__passwordEdit)
+        mainLayout.addLayout(formLayout)
+        mainLayout.addWidget(self._buttonBox)
+        self.setLayout(mainLayout)
+
+    def _accept(self):
+        '''Hide the dialog, update attributes'''
+        if not self.__userBinder.isValid():
+            QMessageBox.critical(self, self.tr('Incorrect JID!'),
+                    self.tr('Please, enter correct jabber id.'))
+            return
+        self.__attributes = self.__userBinder.retrieve()
+        settings.set(**self.__attributes)
+        self.__attributes['password'] = self.__passwordEdit.text()
+        QDialog.accept(self)
+
+
+class NetworkErrorDialog(QMessageBox):
+    '''
+    Dialog that shows network errors
+    @author: Oleg Kandaurov
+    '''
+
+    def __init__(self, parent = None):
+        '''
+        Constructor
+        @type parent: QWidget
+        '''
+        QMessageBox.__init__(self, parent)
+        self.setIcon(QMessageBox.Warning)
+        self.setWindowTitle(self.tr('Network error'))
+        self.setStandardButtons(QMessageBox.Ok);
+        self.setDefaultButton(QMessageBox.Ok);
+
+    def showError(self, info, reason, details):
+        '''
+        Shows specific error information
+        @param info: Short information about error type
+        @type info: str
+        @param reason: Possible reason of error
+        @type reason: str
+        @param details: Technical details
+        @type details: str
+        '''
+        self.setText(info)
+        self.setInformativeText(reason)
+        self.setDetailedText(details)
+        self.exec_()
+
