@@ -24,13 +24,14 @@
 View delegates for core objects
 '''
 
-import hivemind.settings as settings
-import hivemind.resource as resource
 import math
-from hivemind.attribute import *
+from PySide.QtCore import SIGNAL, QRectF, QPointF, Qt
+from PySide.QtGui import QGraphicsScene, QGraphicsItem, QAction, QPen, \
+QPainterPath, QPolygonF, QIcon
+import hivemind.resource as resource
+import hivemind.settings as settings
+from hivemind.attribute import readable, writable
 from hivemind.core import MindMap
-from PySide.QtGui import *
-from PySide.QtCore import *
 
 class MindMapDelegate(QGraphicsScene):
     '''
@@ -145,6 +146,7 @@ class MindMapDelegate(QGraphicsScene):
     def _settingsChanged(self):
         '''Update and position all nodes on the mind map'''
         self.__mindMap.root.updateProperties()
+        self.__rootDelegate.updateNodeBounds()
         self.positionNodes()
 
     def processNotification(self, sender, *values, **args):
@@ -714,7 +716,7 @@ class NodeDelegate(QGraphicsItem):
         # join link shape style
         edgeStyle = self.__node.effectiveEdgeStyle
         # node background color
-        bgColor = self.__node.effectiveBgColor
+        bgColor = self.__node.effectiveBackgroundColor
         if self.__selected:
             bgColor = settings.get('defaultSelectedNodeBackgroundColor')
         painter.setPen(QPen(edgeColor, 1.0))
