@@ -23,26 +23,27 @@
 '''
 GUI factory
 
-@author: Alexander Kulikov
+@author: Alexander Kulikov, Ilya Paramonov
 '''
 
-from hivemind.dialogs import SideSelectionDialog
-try:
-    import PySide.QtMaemo5 #pylint: disable=F0401,E0611,W0611
-    __MAEMO = True
+import hivemind.sysconfig as sysconfig
+from hivemind.dialogs import SideSelectionDialog, NetworkAuthorizationDialog, \
+        NetworkErrorDialog
+
+if sysconfig.PLATFORM == 'maemo':
     from hivemind.maemo.main_window import MaemoMainWindow
     from hivemind.maemo.dialogs import MaemoEditNodeDialog, MaemoEditLabelDialog
     from hivemind.maemo.dialogs import MaemoIconDialog, MaemoAboutDialog, MaemoEditEdgeDialog
     from hivemind.maemo.dialogs import MaemoSettingsDialog, MaemoNetworkConnectionDialog
     from hivemind.maemo.dialogs import MaemoAffiliationDialog, MaemoExtendedMenuDialog
-except ImportError:
-    __MAEMO = None
+    from hivemind.maemo.dialogs import MaemoNetworkServiceDialog, MaemoNetworkClientDialog
+else:
     from hivemind.desktop.main_window import DesktopMainWindow
     from hivemind.desktop.dialogs import DesktopEditNodeDialog, DesktopEditLabelDialog
     from hivemind.desktop.dialogs import DesktopIconDialog, DesktopAboutDialog
-    from hivemind.desktop.dialogs import DesktopEditEdgeDialog
+    from hivemind.desktop.dialogs import DesktopEditEdgeDialog, DesktopNetworkServiceDialog
     from hivemind.desktop.dialogs import DesktopSettingsDialog, DesktopNetworkConnectionDialog
-    from hivemind.desktop.dialogs import DesktopAffiliationDialog
+    from hivemind.desktop.dialogs import DesktopAffiliationDialog, DesktopNetworkClientDialog
 
 '''Default parent for all application dialogs (actually, main window)'''
 __defaultParent = None
@@ -61,7 +62,7 @@ def createMainWindow(actionBag, mindMapScene):
     @type mindMapScene: MindMapDelegate
     '''
     global __defaultParent #pylint: disable=W0603
-    if __MAEMO:
+    if sysconfig.PLATFORM == 'maemo':
         __defaultParent = MaemoMainWindow(actionBag, mindMapScene)
     else:
         __defaultParent = DesktopMainWindow(actionBag, mindMapScene)
@@ -72,7 +73,7 @@ def createEditNodeDialog(node):
     Factory for creating families of related node editing dialogs
     @type node: Node
     '''
-    if __MAEMO:
+    if sysconfig.PLATFORM == 'maemo':
         return MaemoEditNodeDialog(node, __defaultParent)
     return DesktopEditNodeDialog(node, __defaultParent)
 
@@ -81,7 +82,7 @@ def createEditEdgeDialog(node):
     Factory for creating families of related edge editing dialogs
     @type node: Node
     '''
-    if __MAEMO:
+    if sysconfig.PLATFORM == 'maemo':
         return MaemoEditEdgeDialog(node, __defaultParent)
     return DesktopEditEdgeDialog(node, __defaultParent)
 
@@ -90,7 +91,7 @@ def createIconDialog(node):
     Factory for creating families of related icon dialogs
     @type node: Node
     '''
-    if __MAEMO:
+    if sysconfig.PLATFORM == 'maemo':
         return MaemoIconDialog(node, __defaultParent)
     return DesktopIconDialog(node, __defaultParent)
 
@@ -98,7 +99,7 @@ def createAboutDialog():
     '''
     Factory for creating families of related about dialogs
     '''
-    if __MAEMO:
+    if sysconfig.PLATFORM == 'maemo':
         return MaemoAboutDialog(__defaultParent)
     return DesktopAboutDialog(__defaultParent)
 
@@ -107,7 +108,7 @@ def createSettingsDialog():
     Factory for creating families of related settings dialogs
     @type parent: QWidget
     '''
-    if __MAEMO:
+    if sysconfig.PLATFORM == 'maemo':
         return MaemoSettingsDialog(__defaultParent)
     return DesktopSettingsDialog(__defaultParent)
 
@@ -116,38 +117,57 @@ def createEditLabelDialog(node):
     Factory for creating families of related edge label editing dialogs
     @type node: Node
     '''
-    if __MAEMO:
+    if sysconfig.PLATFORM == 'maemo':
         return MaemoEditLabelDialog(node, __defaultParent)
     return DesktopEditLabelDialog(node, __defaultParent)
 
-def createNetworkConnectionDialog(credentials, client):
-    '''
-    Factory for creating families of related network connection dialogs
-    '''
-    if __MAEMO:
-        return MaemoNetworkConnectionDialog(credentials, client, __defaultParent)
-    return DesktopNetworkConnectionDialog(credentials, client, __defaultParent)
-
 def createSideSelectionDialog():
     '''
     Factory for creating families of related side selection dialogs
     '''
     return SideSelectionDialog(__defaultParent)
 
-def createAffiliationDialog():
+def createAffiliationDialog(model):
     '''
     Factory for creating families of related side affiliation dialogs
     '''
-    if __MAEMO:
-        return MaemoAffiliationDialog(__defaultParent)
-    return DesktopAffiliationDialog(__defaultParent)
+    if sysconfig.PLATFORM == 'maemo':
+        return MaemoAffiliationDialog(model, __defaultParent)
+    return DesktopAffiliationDialog(model, __defaultParent)
 
-def createExtendedMenuDialog(actionBag, freezeTime = 0):
+def createNetworkAuthorizationDialog(requestor):
     '''
-    Factory for creating families of related size extended menu dialogs
-    @type actionBag: ActionBag
-    @type freezeTime: int
+    Factory for creating families of network authorization dialogs
+    @type requestor: str
     '''
-    if __MAEMO:
-        return MaemoExtendedMenuDialog(actionBag, freezeTime, __defaultParent)
-    assert None
+    return NetworkAuthorizationDialog(requestor, __defaultParent)
+
+def createNetworkServiceDialog():
+    '''
+    Factory for creating families of related service dialogs
+    '''
+    if sysconfig.PLATFORM == 'maemo':
+        return MaemoNetworkServiceDialog(__defaultParent)
+    return DesktopNetworkServiceDialog(__defaultParent)
+
+def createNetworkClientDialog(rosterModel):
+    '''
+    Factory for creating families of related client dialogs
+    '''
+    if sysconfig.PLATFORM == 'maemo':
+        return MaemoNetworkClientDialog(rosterModel, __defaultParent)
+    return DesktopNetworkClientDialog(rosterModel, __defaultParent)
+
+def createNetworkConnectionDialog():
+    '''
+    Factory for creating families of related network connection dialogs
+    '''
+    if sysconfig.PLATFORM == 'maemo':
+        return MaemoNetworkConnectionDialog(__defaultParent)
+    return DesktopNetworkConnectionDialog(__defaultParent)
+
+def createNetworkErrorDialog():
+    '''
+    Factory for creating families of network error dialogs
+    '''
+    return NetworkErrorDialog(__defaultParent)
