@@ -26,21 +26,23 @@ Main window classes
 '''
 
 import getopt
-import hivemind.parser as parser
-import hivemind.__dirs__ as __dirs__
 import os
 import re
-from hivemind.core import *
-from hivemind.attribute import *
-from hivemind.gui_delegates import *
-from hivemind.gui_widgets import *
-from hivemind.commands import *
-from PySide.QtGui import *
-from PySide.QtCore import *
 from twisted.python import log
+from PySide.QtGui import QActionGroup, QGraphicsBlurEffect, QMessageBox, QUndoStack, \
+QFileDialog, QApplication, QUndoCommand
+from PySide.QtCore import QObject, SIGNAL, QTimer, QLocale, QTranslator, QLibraryInfo
 import hivemind.gui_factory as gui_factory
+import hivemind.parser as parser
+import hivemind.settings as settings
+import hivemind.sysconfig as sysconfig
 from hivemind.action_bag import ActionBag
-
+from hivemind.attribute import writable, adaptCallable, sys
+from hivemind.commands import AddNodeCommand, StateModificationCommand, RemoveNodeCommand, \
+MoveNodeCommand
+from hivemind.core import MindMap
+from hivemind.gui_delegates import MindMapDelegate, NodeLocation
+from hivemind.gui_widgets import readable
 
 # Install qt4reactor as main twisted framework reactor
 from twisted.internet import main
@@ -266,18 +268,7 @@ class MainWindowController(QObject):
     def onItemClicked(self, rightButton, item, parent, childLocation):
         if self.__mode == MainWindowController.MODE_NORMAL:
             if item is not None:
-                extendedMenu = None
-                if settings.get('firstClick') is True:
-                    extendedMenu = gui_factory.createExtendedMenuDialog(self.__actionBag,
-                        5000)
-                    firstClick = False
-                    settings.set(firstClick = firstClick)
-                elif settings.get('useExtendedMenu') is True:
-                    extendedMenu = gui_factory.createExtendedMenuDialog(self.__actionBag)
-                if extendedMenu is not None:
-                    extendedMenu.exec_()
-                else:
-                    self.__mainWindow.showMenu(rightButton, item)
+                self.__mainWindow.showMenu(rightButton, item)
         else:
             if parent.node.folded is None:
                 self._finishNodeMoving(parent, childLocation)
@@ -816,7 +807,7 @@ def run():
             (QLibraryInfo.location(QLibraryInfo.TranslationsPath), locale)):
         app.installTranslator(translatorStd)
     translator = QTranslator()
-    if translator.load(__dirs__.TRANSLATION_PATH_TEMPLATE % locale):
+    if translator.load(sysconfig.TRANSLATION_PATH_TEMPLATE % locale):
         app.installTranslator(translator)
     # launch of reactor and controller
     global reactor
