@@ -26,9 +26,16 @@ Helper widgets
 
 import hivemind.settings as settings
 import hivemind.resource as resource
-from PySide.QtGui import *
-from hivemind.attribute import *
-from PySide.QtCore import *
+from PySide.QtGui import QGraphicsView, QTextEdit, QGraphicsWidget, \
+QListWidgetItem, QListWidget, QGraphicsScene, QAbstractButton, QWidget, \
+QAction, QUndoCommand, QLineEdit, QSpinBox, QCheckBox, QComboBox, QLabel, \
+QToolButton, QIcon, QApplication, QFormLayout, QFontComboBox, QFontDatabase, \
+QHBoxLayout, QGraphicsBlurEffect, QFrame, QPalette, QPushButton, \
+QColorDialog, QPainter, QKeyEvent, QPixmap, QListView, QVBoxLayout, QGridLayout
+from hivemind.attribute import readable, adaptCallable
+from PySide.QtCore import QAbstractAnimation, QObject, SIGNAL, QLocale, Qt, \
+QRect, QEvent, QRectF, QSize, QParallelAnimationGroup, QPropertyAnimation, \
+QPointF, QRegExp, SLOT, QTimeLine
 
 
 class SearchingTrMixin(object):
@@ -474,7 +481,7 @@ class MaemoConnectionStatusWidget(QWidget):
         QWidget.__init__(self, parent)
         self.__connectionButton = ActionImageButton(connectionAction, parent, 48)
         self.__subscribeButton = ActionImageButton(subscribeAction, parent, 48)
-        layout = QHBoxLayout()
+        layout = QVBoxLayout()
         layout.setContentsMargins(5, 5, 5, 5)
         layout.addWidget(self.__connectionButton)
         layout.addWidget(self.__subscribeButton)
@@ -625,12 +632,12 @@ class SettingsCreator(QObject):
         self.__settings = settings
         self.__mainLayout = QFormLayout()
         self.__component = dict()
-        self._createComponents()
+        self._createDecorations()
 
     def getLayout(self):
         return self.__mainLayout
 
-    def _createComponents(self):
+    def _createDecorations(self):
         '''
         Create components
         '''
@@ -657,6 +664,14 @@ class SettingsCreator(QObject):
         self.__mainLayout.addRow(self.tr('Language'), binder)
         self.__component['locale'] = binder
 
+    def _createdefaultZoomLevel(self):
+        '''
+        Create defaultZoomLevel components
+        '''
+        binder = SpinBoxBinder('defaultZoomLevel',
+                settings.get('defaultZoomLevel'), -5, 5)
+        self.__mainLayout.addRow(self.tr('Default zoom level'), binder)
+        self.__component['defaultZoomLevel'] = binder
 
     def _createconfirmDelete(self):
         '''
@@ -825,6 +840,16 @@ class SettingsCreator(QObject):
         self.__mainLayout.addRow(binder)
         self.__component['useExtendedMenu'] = binder
 
+    def _createmaxNodeTextWidth(self):
+        '''
+        Create maxNodeTextWidth component
+        '''
+        binder = SpinBoxBinder('maxNodeTextWidth',
+                settings.get('maxNodeTextWidth'), 50, 1000)
+        binder.setSuffix(self.tr(' px'))
+        self.__mainLayout.addRow(self.tr('Maximum width of node text'), binder)
+        self.__component['maxNodeTextWidth'] = binder
+
 
 class ComponentBinder(QObject):
     '''
@@ -857,6 +882,15 @@ class ComponentBinder(QObject):
             return {self._paramName: self._value}
         return None
 
+    def _getName(self):
+        '''Retrieve name of parameter'''
+        return self._paramName
+
+    def _getValue(self):
+        '''Retrieve current value'''
+        if self.isValid(self._value):
+            return self._value
+
     def _setValue(self, value):
         '''
         Sets new value
@@ -865,6 +899,9 @@ class ComponentBinder(QObject):
         if self.isValid(value):
             self._value = value
 
+    name = property(_getName, None, None, 'Parameter name')
+    value = property(_getValue, None, None, 'Binder value')
+
 
 class LineEditBinder(QLineEdit, ComponentBinder):
     '''
@@ -1160,53 +1197,174 @@ class FullScreenExitButton(QToolButton):
         return QToolButton.eventFilter(self, obj, event)
 
 
-class AffiliationDelegate(QStyledItemDelegate):
+class SlideWidget(QWidget):
     '''
-    Delegate for affiliation combo box
-    @author: Oleg Kandaurov
+    Slide widget
+    @author: Alexander Kulikov
     '''
 
-    readable('supportedAffiliations')
+    __FRAMES = 50
+    '''Count of animation frames'''
+    __DURATION = 200
+    '''Animation duration'''
 
-    def __init__(self, parent = None):
-        '''
-        Constructor
-        '''
-        QStyledItemDelegate.__init__(self, parent)
-        self.__supportedAffiliations = {'owner': self.tr('Owner'),
-                'member' : self.tr('Member'),
-                'outcast': self.tr('Outcast'),
-                'publisher': self.tr('Publisher')}
+    __MINIMUM_VISIBLE_WIDTH = 24
+    '''Width of part widget which will be visible always'''
 
-    def createEditor(self, parent, option, index):
-        '''
-        Returns the widget used to edit the item specified by index for editing.
-        The parent widget and style option are used to control how the editor widget appears.
-        '''
-        editor = QComboBox(parent)
-        for data, name in self.__supportedAffiliations.iteritems():
-            editor.addItem(name, data)
-        return editor
+    __MIN_DRAG_PATH = 25
+    '''Minimum drag path length for the Maemo platform'''
 
-    def setEditorData(self, editor, index):
-        '''
-        Sets the data to be displayed and edited by the editor
-        from the data model item specified by the model index.
-        '''
-        value = index.model().data(index, Qt.EditRole)
-        if value: editor.setCurrentIndex(editor.findData(value))
+    LEFT = 'left'
+    '''Widget is attached to the left side of the parent'''
 
-    def setModelData(self, editor, model, index):
+    def __init__(self, dockArea, parent):
         '''
-        Gets data from the editor widget and stores
-        it in the specified model at the item index.
+        Initialize widget
+        @param dockArea: side of parent widget to which widget will be attached
+        @type dockArea: string
+        @type parent: MainView
         '''
-        value = editor.itemData(editor.currentIndex())
-        if value: model.setData(index, value, Qt.EditRole)
+        QWidget.__init__(self, parent)
+        self.__dockArea = dockArea
+        self.__timeLine = QTimeLine(self.__DURATION, self)
+        self.__timeLine.setFrameRange(0, self.__FRAMES)
+        self.__timeLine.connect(SIGNAL('frameChanged(int)'),
+                adaptCallable(self._updateFrame))
+        self.__direction = self.__lastClick = None
+        self.__draggedPath = 0
+        self.__animationLock = False
+        palette = QPalette()
+        backgroundColor = self.palette().color(QPalette.Window)
+        backgroundColor.setAlpha(64)
+        palette.setColor(QPalette.Base, backgroundColor)
+        self.setPalette(palette)
+        self.setAutoFillBackground(True)
+        self.connect(parent, SIGNAL('resized'), adaptCallable(self._updatePosition))
+        self._updateFrame(0)
+        self._createDecorations()
 
-    def updateEditorGeometry(self, editor, option, index):
+    def _createDecorations(self):
+        '''Create and place decoration components'''
+        mainLayout = QGridLayout()
+        QWidget.setLayout(self, mainLayout)
+        mainLayout.setContentsMargins(0, 0, 0, 0)
+        mainLayout.setSpacing(0)
+        if self.__dockArea == self.LEFT:
+            btn = QLabel()
+            btn.setPixmap(resource.getImage('slide_button'))
+            btn.setFixedWidth(self.__MINIMUM_VISIBLE_WIDTH)
+            mainLayout.addWidget(btn, 1, 2)
+            side = QLabel()
+            side.setPixmap(resource.getImage('slide_side'))
+            btn.setFixedWidth(self.__MINIMUM_VISIBLE_WIDTH)
+            side.setScaledContents(True)
+            mainLayout.addWidget(side, 0, 2)
+            mainLayout.setRowStretch(0, 2)
+            side = QLabel()
+            side.setPixmap(resource.getImage('slide_side'))
+            btn.setFixedWidth(self.__MINIMUM_VISIBLE_WIDTH)
+            side.setScaledContents(True)
+            mainLayout.addWidget(side, 2, 2)
+            mainLayout.setRowStretch(2, 2)
+
+    def _updateFrame(self, value):
         '''
-        Updates the editor for the item specified
-        by index according to the style option given.
+        Update state of widget
+        @type value: int
         '''
-        editor.setGeometry(option.rect)
+        width = self.width() - self.__MINIMUM_VISIBLE_WIDTH
+        if self.__dockArea == self.LEFT:
+            value = width * (self.__FRAMES - value) / self.__FRAMES
+        if self.__dockArea == self.LEFT:
+            self.move(-value, 0)
+
+    def _getCurrentFrame(self):
+        '''
+        Get current frame of animation
+        @rtype: int
+        '''
+        width = float(self.width() - self.__MINIMUM_VISIBLE_WIDTH)
+        if self.__dockArea == self.LEFT:
+            value = self.pos().x() / width + 1.0
+        return int(value * self.__FRAMES)
+
+    def slideOpen(self):
+        '''Open slide widget'''
+        self.__timeLine.setFrameRange(self._getCurrentFrame(), self.__FRAMES)
+        self.__timeLine.setDirection(QTimeLine.Forward)
+        self.__timeLine.start()
+
+    def slideClose(self):
+        '''Close slide widget'''
+        self.__timeLine.setDirection(QTimeLine.Backward)
+        self.__timeLine.setFrameRange(0, self._getCurrentFrame())
+        self.__timeLine.start()
+
+    def _updatePosition(self, size):
+        '''
+        Update position on the parent area
+        @type size: QSize
+        '''
+        if self.__dockArea == self.LEFT:
+            self.setFixedHeight(size.height())
+        self._updateFrame(self.__timeLine.currentFrame())
+
+    def mousePressEvent(self, event):
+        '''
+        Mouse press event handler
+        @type event: QMouseEvent
+        '''
+        QWidget.mousePressEvent(self, event)
+        self.__direction = None
+        self.__lastClick = event.pos()
+        self.__animationLock = False
+        self.__draggedPath = 0
+
+    def _startAnimation(self, direction):
+        '''
+        Configure animation timeline according to the chosen direction
+        @type direction: QTimeLine.Direction
+        '''
+        self.__timeLine.setDirection(direction)
+        if direction == QTimeLine.Forward:
+            self.__timeLine.setFrameRange(self._getCurrentFrame(), self.__FRAMES)
+        else:
+            self.__timeLine.setFrameRange(0, self._getCurrentFrame())
+        self.__timeLine.start()
+
+    def mouseMoveEvent(self, event):
+        '''
+        Mouse move event handerl
+        @type event: QMouseEvent
+        '''
+        QWidget.mouseMoveEvent(self, event)
+        if event.buttons() == Qt.LeftButton and not self.__animationLock:
+            newX = event.pos().x() - self.__lastClick.x() + self.pos().x()
+            self.__draggedPath += event.posF().x() - self.__lastClick.x()
+            if self.__dockArea == self.LEFT:
+                if event.pos().x() - self.__lastClick.x() > 0:
+                    self.__direction = QTimeLine.Forward
+                elif event.pos().x() - self.__lastClick.x() < 0:
+                    self.__direction = QTimeLine.Backward
+                if abs(self.__draggedPath) > self.__MIN_DRAG_PATH and \
+                not self.__animationLock:
+                    self.__animationLock = True
+                    self._startAnimation(self.__direction)
+                newX = min(0, max(newX, -(self.width() - self.__MINIMUM_VISIBLE_WIDTH)))
+                self.move(newX, 0)
+
+    def setLayout(self, layout):
+        '''
+        Set layout
+        @type layout: QLayout
+        '''
+        self.layout().addLayout(layout, 0, 0, 3, 1)
+
+    def mouseReleaseEvent(self, event):
+        '''
+        Mouse release event handler
+        @type event: QMouseEvent
+        '''
+        QWidget.mouseReleaseEvent(self, event)
+        if self.__direction is not None and not self.__animationLock:
+            self._startAnimation(self.__direction)
