@@ -24,10 +24,16 @@
 Dialogs for Maemo platform
 '''
 
-from PySide.QtGui import *
-from PySide.QtCore import *
-from hivemind.dialogs import *
-from hivemind.gui_widgets import *
+import hivemind.resource as resource
+from PySide.QtGui import QFrame, QWidget, QGridLayout, QStackedWidget, QVBoxLayout, \
+QRadioButton, QHBoxLayout, QToolBar, QIcon, QPalette, QPushButton, QLabel, \
+QTextBrowser, QAbstractSlider, QTabWidget, QDialog, QFont, QDesktopServices
+from PySide.QtCore import Qt, SIGNAL, QSize, QTimer, QUrl
+from hivemind.dialogs import EditNodeDialog, EditLabelDialog, IconDialog, \
+AboutDialog, EditEdgeDialog, SettingsDialog, AffiliationDialog, NetworkServiceDialog, \
+NetworkClientDialog, NetworkConnectionDialog
+from hivemind.gui_widgets import ScalingWidget, SettingsCreator, ActionImageButton
+from hivemind.attribute import adaptCallable
 import hivemind.__version__ as __version__
 
 
@@ -89,14 +95,18 @@ class MaemoEditNodeDialog(MaemoDialogMixin, EditNodeDialog):
         self.__stackedWidget = QStackedWidget()
         self.__textIndex = self.__stackedWidget.addWidget(editWidget)
         self.__htmlIndex = self.__stackedWidget.addWidget(htmlWidget)
-        mainLayout = QGridLayout()
+        mainLayout = QVBoxLayout()
         self.__showText = QRadioButton(self.tr('Text'))
         self.__showHtml = QRadioButton(self.tr('Source'))
         self.__showText.setChecked(True)
-        mainLayout.addWidget(self.__stackedWidget, 0, 0, 2, 6)
-        mainLayout.addWidget(self.__showText, 2, 0)
-        mainLayout.addWidget(self.__showHtml, 2, 1)
-        mainLayout.addWidget(self._buttonBox, 2, 2, 1, 4)
+        mainLayout.addWidget(self.__stackedWidget)
+        bottomLayout = QHBoxLayout()
+        bottomLayout.addWidget(self.__showText)
+        bottomLayout.addWidget(self.__showHtml)
+        bottomLayout.addWidget(self._propagateFormatting)
+        bottomLayout.addStretch()
+        bottomLayout.addWidget(self._buttonBox)
+        mainLayout.addLayout(bottomLayout)
         self._editor.setFocus()
         self.setLayout(mainLayout)
         self.__showHtml.connect(SIGNAL('toggled(bool)'), adaptCallable(self._changedMode))
@@ -145,6 +155,7 @@ class MaemoEditNodeDialog(MaemoDialogMixin, EditNodeDialog):
         '''
         self.__showText.setVisible(isHtml)
         self.__showHtml.setVisible(isHtml)
+        self._propagateFormatting.setVisible(not isHtml)
 
 class MaemoEditLabelDialog(MaemoDialogMixin, EditLabelDialog):
     '''
@@ -185,7 +196,11 @@ class MaemoEditLabelDialog(MaemoDialogMixin, EditLabelDialog):
         mainLayout.addWidget(self._comboSize, 0, 7, 1, 3)
         mainLayout.addWidget(scalingWidget, 1, 0, 1, 10)
         mainLayout.addLayout(secondaryLayout, 2, 0, 1, 10)
-        mainLayout.addWidget(self._buttonBox, 3, 0, 1, 10)
+        bottomLayout = QHBoxLayout()
+        bottomLayout.addWidget(self._propagateFormatting)
+        bottomLayout.addStretch()
+        bottomLayout.addWidget(self._buttonBox)
+        mainLayout.addLayout(bottomLayout, 3, 0, 1, 10)
         self.setLayout(mainLayout)
         self._editor.setFocus()
         QWidget.setTabOrder(self._editor, self._buttonBox)
@@ -318,30 +333,18 @@ class MaemoEditEdgeDialog(MaemoDialogMixin, EditEdgeDialog):
 
     def _initComponents(self):
         '''Form initialization'''
-        widthLayout = QHBoxLayout()
-        widthLayout.addWidget(self._widthParent)
-        widthLayout.addWidget(self._widthThin)
-        widthLayout.addWidget(self._widthOne)
-        widthLayout.addWidget(self._widthTwo)
-        widthLayout.addWidget(self._widthFour)
-        widthLayout.addWidget(self._widthEight)
-        styleLayout = QHBoxLayout()
-        styleLayout.addWidget(self._styleParent)
-        styleLayout.addWidget(self._styleLinear)
-        styleLayout.addWidget(self._styleBezier)
-        styleLayout.addWidget(self._styleSharpLinear)
-        styleLayout.addWidget(self._styleSharpBezier)
         colorLayout = QHBoxLayout()
         colorLayout.addWidget(self._colorParent)
         colorLayout.addWidget(self._colorButton)
         mainLayout = QGridLayout()
         mainLayout.addWidget(self._widthLabel, 0, 0)
-        mainLayout.addLayout(widthLayout, 1, 0)
-        mainLayout.addWidget(self._styleLabel, 2, 0)
-        mainLayout.addLayout(styleLayout, 3, 0)
-        mainLayout.addWidget(self._colorLabel, 4, 0)
-        mainLayout.addLayout(colorLayout, 5, 0)
-        mainLayout.addWidget(self._buttonBox, 6, 0)
+        mainLayout.addWidget(self._styleLabel, 0, 1)
+        mainLayout.addWidget(self._edgeWidthComboBox, 1, 0)
+        mainLayout.addWidget(self._edgeStyleComboBox, 1, 1)
+        mainLayout.addWidget(self._nodeStyleLabel, 2, 0, 1, 2)
+        mainLayout.addWidget(self._nodeStyleComboBox, 3, 0, 1, 2)
+        mainLayout.addLayout(colorLayout, 4, 0, 1, 2)
+        mainLayout.addWidget(self._buttonBox, 5, 0, 1, 2)
         self.setLayout(mainLayout)
 
 
@@ -380,12 +383,16 @@ class MaemoSettingsDialog(MaemoDialogMixin, SettingsDialog):
         self._autosave = SettingsCreator(['autosaveEnabled', 'autosaveInterval'])
         autosaveTab = QWidget()
         autosaveTab.setLayout(self._autosave.getLayout())
+        self._maxTextWidth = SettingsCreator(['defaultZoomLevel','maxNodeTextWidth'])
+        otherTab = QWidget()
+        otherTab.setLayout(self._maxTextWidth.getLayout())
         tabWidget.addTab(generalTab, self.tr('General'))
         tabWidget.addTab(nodeTab, self.tr('Node'))
         tabWidget.addTab(edgeTab, self.tr('Edge'))
         tabWidget.addTab(edgeLabelTab, self.tr('Edge Label'))
         tabWidget.addTab(animationTab, self.tr('Animation'))
         tabWidget.addTab(autosaveTab, self.tr('Autosave'))
+        tabWidget.addTab(otherTab, self.tr('View'))
         mainLayout = QVBoxLayout()
         mainLayout.addWidget(tabWidget)
         mainLayout.addWidget(self._buttonBox)
@@ -401,25 +408,17 @@ class MaemoSettingsDialog(MaemoDialogMixin, SettingsDialog):
         self._newSettings.append(self._edgeLabel.retrieve())
         self._newSettings.append(self._animation.retrieve())
         self._newSettings.append(self._autosave.retrieve())
+        self._newSettings.append(self._maxTextWidth.retrieve())
         SettingsDialog._accept(self)
 
-class MaemoNetworkConnectionDialog(MaemoDialogMixin, NetworkConnectionDialog):
-    '''
-    Network connection dialog for Maemo platform
-    @author: Oleg Kandaurov
-    '''
-    def __init__(self, credentials, client, parent = None):
-        NetworkConnectionDialog.__init__(self, credentials, client, parent)
-        MaemoDialogMixin.__init__(self)
-
 
 class MaemoAffiliationDialog(MaemoDialogMixin, AffiliationDialog):
     '''
     Affiliation dialog for Maemo platform
     @author: Oleg Kandaurov
     '''
-    def __init__(self, parent = None):
-        AffiliationDialog.__init__(self, parent)
+    def __init__(self, model, parent = None):
+        AffiliationDialog.__init__(self, model, parent)
         MaemoDialogMixin.__init__(self)
 
 
@@ -507,6 +506,39 @@ class MaemoExtendedMenuDialog(QDialog):
         return button
 
 
+class MaemoNetworkServiceDialog(MaemoDialogMixin, NetworkServiceDialog):
+    '''
+    Service dialog for Maemo platfrom
+    @author: Oleg Kandaurov
+    '''
+
+    def __init__(self, parent = None):
+        NetworkServiceDialog.__init__(self, parent)
+        MaemoDialogMixin.__init__(self)
+
+
+class MaemoNetworkClientDialog(MaemoDialogMixin, NetworkClientDialog):
+    '''
+    Client dialog for Maemo platfrom
+    @author: Oleg Kandaurov
+    '''
+
+    def __init__(self, rosterModel, parent = None):
+        NetworkClientDialog.__init__(self, rosterModel, parent)
+        MaemoDialogMixin.__init__(self)
+
+
+class MaemoNetworkConnectionDialog(MaemoDialogMixin, NetworkConnectionDialog):
+    '''
+    Connection dialog for Maemo platfrom
+    @author: Oleg Kandaurov
+    '''
+
+    def __init__(self, parent = None):
+        NetworkConnectionDialog.__init__(self, parent)
+        MaemoDialogMixin.__init__(self)
+
+
 def openWebsite():
     '''Open project web page'''
     QDesktopServices.openUrl(QUrl(
