@@ -23,10 +23,14 @@
 '''
 Abstract main window class
 '''
-from PySide.QtGui import *
-from PySide.QtCore import *
-from hivemind.gui_widgets import *
-from hivemind.gui_delegates import *
+import hivemind.settings as settings
+from PySide.QtGui import QPainter, QGraphicsView, QPalette, QMainWindow
+from PySide.QtCore import Qt, SIGNAL, QObject, QTimer, QRect, QParallelAnimationGroup, \
+QSequentialAnimationGroup, QPropertyAnimation, QEasingCurve
+from hivemind.gui_widgets import ActionImageButton, SearchingTrMixin, WidgetVisibilityAnimation
+from hivemind.gui_delegates import math, readable
+import settings
+import resource
 
 class MainView(QGraphicsView):
     '''
@@ -97,9 +101,6 @@ class MainView(QGraphicsView):
     __ZOOM_IN_COEFFICIENT = 1.25
     '''View scale coefficient for zoom in action'''
 
-    __ZOOM_OUT_COEFFICIENT = 0.8
-    '''View scale coefficient for zoom out action'''
-
     __MAX_ZOOM_LEVEL = 8
     '''Maximum value for zoom level'''
 
@@ -109,12 +110,12 @@ class MainView(QGraphicsView):
     def _zoom(self, scaleFactor):
         '''
         Change the scale factor of the mind map.
-        @parame scaleFactor: the scale of the map to apply (__ZOOM_IN_COEFFICIENT or
-        _ZOOM_OUT_COEFFICIENT)
-        @type scaleFactor: double
+        @parame scaleFactor: which way to zoom and how many times, e.g. -1 zoom out once
+        @type scaleFactor: int
         '''
-        self.scale(scaleFactor, scaleFactor)
-        self.__zoomLevel += 1 if scaleFactor > 1 else - 1
+        scale = MainView.__ZOOM_IN_COEFFICIENT ** scaleFactor
+        self.scale(scale, scale)
+        self.__zoomLevel += scaleFactor
         self._updateZoomActionsState()
 
     def _updateZoomActionsState(self):
@@ -130,11 +131,11 @@ class MainView(QGraphicsView):
 
     def _zoomIn(self):
         '''Zoom in scene view'''
-        self._zoom(MainView.__ZOOM_IN_COEFFICIENT)
+        self._zoom(1)
 
     def _zoomOut(self):
         '''Zoom out scene view'''
-        self._zoom(MainView.__ZOOM_OUT_COEFFICIENT)
+        self._zoom(-1)
 
     def _resetView(self):
         '''
@@ -142,11 +143,20 @@ class MainView(QGraphicsView):
         the viewport to ensure that the root item is centered in the view.
         '''
         self.resetTransform()
-        self.scale(1.44, 1.44)
+        scale = MainView.__ZOOM_IN_COEFFICIENT ** settings.get('defaultZoomLevel')
+        self.scale(scale, scale)
         self.__zoomLevel = 0
         self._updateZoomActionsState()
         self.centerOn(self.scene().rootDelegate)
 
+    def resizeEvent(self, event):
+        '''
+        Resize event handler
+        @type event: QResizeEvent
+        '''
+        self.emit(SIGNAL('resized'), event.size())
+        return QGraphicsView.resizeEvent(self, event)
+
 
 class MaemoNodeMenu(QObject):
     '''
