@@ -31,8 +31,11 @@ Provides functions for creating a mind map object from XML file and vice versa
 import parser #pylint: disable=W0406
 
 from lxml import etree as xml
-from hivemind.core import *
-from hivemind.commands import *
+from PySide.QtCore import QFile, QIODevice, QTextStream
+from PySide.QtGui import QTextDocument, QColor, QFont, QUndoStack
+from hivemind.core import Node, MindMap, Cloud, Attribute, AttributeRegistry
+from hivemind.commands import AddNodeCommand, MoveNodeCommand, RemoveNodeCommand, \
+StateModificationCommand
 
 
 def _parseNode(root, parent = None):
@@ -60,7 +63,11 @@ def _parseNode(root, parent = None):
     nodeColor = attributes.pop('color', None)
     if nodeColor is not None: storeAttrs['color'] = nodeColor
     backgroundColor = attributes.pop('background_color', None)
-    if backgroundColor is not None: storeAttrs['background_color'] = backgroundColor
+    if backgroundColor is not None: storeAttrs['backgroundColor'] = backgroundColor
+    if attributes.pop('propagate_formatting', None):
+        storeAttrs['propagateNodeFormatting'] = True
+    else:
+        storeAttrs['propagateNodeFormatting'] = False
     node = parent.createChildPrototype(**attributes) if parent else Node(**attributes)
     icons = []
     # parse child node attributes
@@ -91,6 +98,10 @@ def _parseNode(root, parent = None):
                 if color: storeAttrs['labelColor'] = color
                 font = labelAttributes.get('font')
                 if font: storeAttrs['labelFont'] = font
+                if labelAttributes.get('propagate_formatting'):
+                    storeAttrs['propagateLabelFormatting'] = True
+                else:
+                    storeAttrs['propagateLabelFormatting'] = False
         elif element.tag == 'cloud':
             storeAttrs['cloud'] = Cloud(**_castAttributes(element.attrib))
         elif element.tag == 'font':
@@ -127,6 +138,9 @@ __COLORS = set(('color', 'background_color', 'edgeColor', 'labelColor'))
 __FONTS = set(('font', 'labelFont'))
 '''QFont attributes'''
 
+__BOOLEANS = set(('folded', 'propagate_formatting'))
+'''Attribute that store boolean values'''
+
 def _castAttributes(attributes, toLowerCase = True):
     '''
     Cast attribute values from string to more convenient type
@@ -150,7 +164,7 @@ def _castAttributes(attributes, toLowerCase = True):
             # The 'thin' defined in mind map file format, but it is equals to '1' value
             # in paint context. For compatibility used mod10(width) value
             casted[attrName] = 11 if attrValue == 'thin' else int(attrValue)
-        elif attrName == 'folded':
+        elif attrName in __BOOLEANS:
             casted[attrName] = True
         elif attrName in __FONTS:
 #           Font attribute is a comma-separated list of the attributes of QFont object.
@@ -190,8 +204,9 @@ def _toString(attributes, toUpperCase = True):
         elif attrName in __COLORS:
             stringAttributes[strAttrKey] = str(attrValue.name())
         # replace 'True' with FreeMind format specified value 'true'
-        elif attrName == 'folded':
-            stringAttributes[strAttrKey] = 'true' # value 'false' not stored in file
+        elif attrName in __BOOLEANS:
+            if attrValue is True:
+                stringAttributes[strAttrKey] = 'true' # value 'false' not stored in file
         elif attrName == 'width':
             stringAttributes[strAttrKey] = str(attrValue) if attrValue != 11 else 'thin'
         elif attrName == 'font':
@@ -216,6 +231,12 @@ def _nodeToXml(root):
     # do not store position attribute if node is not first-level child
     if root.parent is not None and root.parent.parent is not None:
         nodeAttributes.pop('left', None)
+    if 'backgroundColor' in nodeAttributes:
+        backgroundColor = nodeAttributes.pop('backgroundColor')
+        nodeAttributes['background_color'] = backgroundColor
+    if 'propagateNodeFormatting' in nodeAttributes:
+        propagateNodeFormatting = nodeAttributes.pop('propagateNodeFormatting')
+        nodeAttributes['propagate_formatting'] = propagateNodeFormatting
     xmlElement = xml.Element('node')
     xmlElement.attrib.update(_toString(nodeAttributes))
     if root.isHtml():
@@ -250,6 +271,8 @@ def _nodeToXml(root):
             attrsStore['color'] = root.labelColor
         if root.labelFont:
             attrsStore['font'] = root.labelFont
+        if root.propagateLabelFormatting:
+            attrsStore['propagate_formatting'] = root.propagateLabelFormatting
     if attrsStore:
         label = xml.Element('label')
         label.attrib.update(_toString(attrsStore))
