@@ -28,8 +28,8 @@ Application resource manager
 
 import os
 import hivemind.settings as settings
-import hivemind.__dirs__ as __dirs__
-from PySide.QtGui import *
+import hivemind.sysconfig as sysconfig
+from PySide.QtGui import QIcon, QImage, QPixmap, QPixmapCache
 
 __ICONS = {}
 '''Hash table containing icons'''
@@ -52,7 +52,7 @@ def getImage(name):
     @return: new image object on first call, cached image afterwards 
     @rtype: QPixmap
     '''
-    fullname = os.path.join(__dirs__.BASEDIR, 'images', name + '.png')
+    fullname = os.path.join(sysconfig.BASEDIR, 'images', name + '.png')
     image = QPixmap()
     if not QPixmapCache.find(fullname, image):
         image = QPixmap(fullname)
@@ -87,7 +87,7 @@ def _loadIcons():
     Load icons to the hash table using a list of
     names of icons from the configuration file
     '''
-    path = os.path.join(__dirs__.BASEDIR, 'icons')
+    path = os.path.join(sysconfig.BASEDIR, 'icons')
     for name in settings.get("listIcons"):
         fullPath = os.path.join(path, name + '.png')
         image = QImage(fullPath)
