@@ -15,20 +15,175 @@
     </message>
 </context>
 <context>
-    <name>DesktopAboutDialog</name>
+    <name>ActionBag</name>
     <message>
-        <location filename="dialogs.py" line="224"/>
-        <source>HiveMind - Collaborative mind map editor&lt;br&gt;
-            Copyright &amp;copy; 2010 HiveMind developers&lt;br&gt;&lt;br&gt;
-            License: &lt;a href=&quot;http://www.gnu.org/licenses/gpl-3.0.html&quot;&gt;
-            GNU General Public License Version 3&lt;/a&gt;&lt;br&gt;&lt;br&gt;
-            HiveMind development is supported by&lt;br&gt;
-            &lt;a href=&quot;http://fruct.org/&quot;&gt; Open Innovations Framework Program FRUCT&lt;/a&gt;
-            </source>
+        <location filename="action_bag.py" line="61"/>
+        <source>&amp;New</source>
+        <translation>&amp;Создать</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="62"/>
+        <source>&amp;Open</source>
+        <translation>&amp;Открыть</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="63"/>
+        <source>&amp;Save</source>
+        <translation>&amp;Сохранить</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="64"/>
+        <source>Save as</source>
+        <translation>Сохранить как</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="65"/>
+        <source>Edit edge</source>
+        <translation>Изменить стиль ребра</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="66"/>
+        <source>Edit label</source>
+        <translation>Изменить метку ребра</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="67"/>
+        <source>Edit node</source>
+        <translation>Изменить узел</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="68"/>
+        <source>Select icons</source>
+        <translation>Выбрать пиктограммы</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="69"/>
+        <source>Fold node</source>
+        <translation>Свернуть поддерево</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="74"/>
+        <source>Remove node</source>
+        <translation>Удалить узел</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="75"/>
+        <source>Move node</source>
+        <translation>Переместить узел</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="76"/>
+        <source>&amp;Undo</source>
+        <translation>&amp;Отменить</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="77"/>
+        <source>&amp;Redo</source>
+        <translation>&amp;Повторить</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="78"/>
+        <source>&amp;Share mind map</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="251"/>
+        <location filename="action_bag.py" line="79"/>
+        <source>&amp;Edit shared mind map</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="80"/>
+        <source>&amp;Finish collaboration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="81"/>
+        <source>Zoom in</source>
+        <translation>Увеличить</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="82"/>
+        <source>Zoom out</source>
+        <translation>Уменьшить</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="83"/>
+        <source>&amp;About</source>
+        <translation>&amp;О программе</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="84"/>
+        <source>E&amp;xit</source>
+        <translation>В&amp;ыход</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="85"/>
+        <source>Settings</source>
+        <translation>Настройки</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="92"/>
+        <source>Parent</source>
+        <translation>Родителя</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="87"/>
+        <source>Thin</source>
+        <translation>Тонкая</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="93"/>
+        <source>Linear</source>
+        <translation>Прямая</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="94"/>
+        <source>Bezier</source>
+        <translation>Кривая</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="95"/>
+        <source>Sharp linear</source>
+        <translation>Заостр. прямая</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="96"/>
+        <source>Sharp bezier</source>
+        <translation>Заостр. кривая</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="99"/>
+        <source>&amp;Edit participants access</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="70"/>
+        <source>New child node</source>
+        <translation>Новый подчинённый узел</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="71"/>
+        <source>New sibling node below</source>
+        <translation>Новый смежный узел ниже текущего</translation>
+    </message>
+    <message>
+        <location filename="action_bag.py" line="72"/>
+        <source>New sibling node above</source>
+        <translation>Новый смежный узел выше текущего</translation>
+    </message>
+</context>
+<context>
+    <name>AffiliationDialog</name>
+    <message>
+        <location filename="dialogs.py" line="990"/>
+        <source>Edit participant access</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DesktopAboutDialog</name>
+    <message>
+        <location filename="dialogs.py" line="253"/>
         <source>
             Please use &lt;a href=&quot;https://linuxlab.corp7.uniyar.ac.ru/projects/hivemind/issues/new&quot;&gt;
             https://linuxlab.corp7.uniyar.ac.ru/&lt;/a&gt; to report bugs.&lt;br&gt;&lt;br&gt;
@@ -55,34 +210,47 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="260"/>
-        <source>
-            Nicu Buculei&lt;br&gt;
-            &amp;nbsp;&amp;nbsp;&lt;a href=&quot;http://nicubunu.ro&quot;&gt;nicubunu.ro&lt;/a&gt;&lt;br&gt;
-            &amp;nbsp;&amp;nbsp;HiveMind logo&lt;br&gt;
-            </source>
+        <location filename="dialogs.py" line="267"/>
+        <source>&lt;h4&gt;Version %s&lt;/h4&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="263"/>
-        <source>&lt;h4&gt;Version %s&lt;/h4&gt;</source>
+        <location filename="dialogs.py" line="264"/>
+        <source>
+            Nicu Buculei&lt;br&gt;
+            &amp;nbsp;&amp;nbsp;&lt;a href=&quot;http://nicubunu.ro&quot;&gt;nicubunu.ro&lt;/a&gt;&lt;br&gt;
+            &amp;nbsp;&amp;nbsp;HiveMind logo&lt;br&gt;&lt;br&gt;
+            Mentalrey&lt;br&gt;
+            &amp;nbsp;&amp;nbsp;&lt;a href=&quot;http://www.mentalrey.it/&quot;&gt;mentalrey.it&lt;/a&gt;&lt;br&gt;
+            &amp;nbsp;&amp;nbsp;Notification icons&lt;br&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="dialogs.py" line="226"/>
+        <source>HiveMind - Collaborative mind map editor&lt;br&gt;
+            Copyright &amp;copy; 2010-2011 HiveMind developers&lt;br&gt;&lt;br&gt;
+            License: &lt;a href=&quot;http://www.gnu.org/licenses/gpl-3.0.html&quot;&gt;
+            GNU General Public License Version 3&lt;/a&gt;&lt;br&gt;&lt;br&gt;
+            HiveMind development is supported by&lt;br&gt;
+            &lt;a href=&quot;http://fruct.org/&quot;&gt; Open Innovations Framework Program FRUCT&lt;/a&gt;
+            </source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>DesktopEditLabelDialog</name>
     <message>
-        <location filename="dialogs.py" line="128"/>
+        <location filename="dialogs.py" line="130"/>
         <source>Bold</source>
         <translation>Жирный</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="131"/>
+        <location filename="dialogs.py" line="133"/>
         <source>Italic</source>
         <translation>Курсив</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="134"/>
+        <location filename="dialogs.py" line="136"/>
         <source>Underline</source>
         <translation>Подчеркнутый</translation>
     </message>
@@ -133,12 +301,12 @@
 <context>
     <name>DesktopIconDialog</name>
     <message>
-        <location filename="dialogs.py" line="181"/>
+        <location filename="dialogs.py" line="183"/>
         <source>Selected icons</source>
         <translation>Выбранные пиктограммы</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="182"/>
+        <location filename="dialogs.py" line="184"/>
         <source>Available icons</source>
         <translation>Доступные пиктограммы</translation>
     </message>
@@ -146,58 +314,73 @@
 <context>
     <name>DesktopMainWindow</name>
     <message>
-        <location filename="main_window.py" line="88"/>
+        <location filename="main_window.py" line="131"/>
         <source>&amp;File</source>
         <translation>&amp;Файл</translation>
     </message>
     <message>
-        <location filename="main_window.py" line="95"/>
+        <location filename="main_window.py" line="138"/>
         <source>&amp;Edit</source>
         <translation>&amp;Правка</translation>
     </message>
     <message>
-        <location filename="main_window.py" line="104"/>
+        <location filename="main_window.py" line="148"/>
         <source>&amp;Help</source>
         <translation>&amp;Справка</translation>
     </message>
     <message>
-        <location filename="main_window.py" line="112"/>
+        <location filename="main_window.py" line="153"/>
         <source>File</source>
         <translation>Файл</translation>
     </message>
     <message>
-        <location filename="main_window.py" line="117"/>
+        <location filename="main_window.py" line="158"/>
         <source>Edit</source>
         <translation>Правка</translation>
     </message>
     <message>
-        <location filename="main_window.py" line="100"/>
+        <location filename="main_window.py" line="143"/>
         <source>&amp;Collaboration</source>
         <translation>&amp;Совместная работа</translation>
     </message>
     <message>
-        <location filename="main_window.py" line="53"/>
-        <source>Edge parameters</source>
-        <translation>Параметры ребра</translation>
+        <location filename="main_window.py" line="161"/>
+        <source>View</source>
+        <translation>Вид</translation>
+    </message>
+    <message>
+        <location filename="main_window.py" line="164"/>
+        <source>Connection status</source>
+        <translation>Статус соединения</translation>
+    </message>
+    <message>
+        <location filename="main_window.py" line="97"/>
+        <source>Edge properties</source>
+        <translation>Свойства ребра</translation>
     </message>
 </context>
 <context>
     <name>DesktopSettingsDialog</name>
     <message>
-        <location filename="dialogs.py" line="339"/>
+        <location filename="dialogs.py" line="343"/>
         <source>General settings</source>
         <translation>Общие настройки</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="343"/>
+        <location filename="dialogs.py" line="347"/>
         <source>Node settings</source>
         <translation>Настройки узлов</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="347"/>
+        <location filename="dialogs.py" line="351"/>
         <source>Edge &amp;&amp; label settings</source>
         <translation>Настройки рёбер и меток</translation>
     </message>
+    <message>
+        <location filename="dialogs.py" line="354"/>
+        <source>Autosave settings</source>
+        <translation>Настройки автоматического сохранения</translation>
+    </message>
 </context>
 <context>
     <name>EditEdgeDialog</name>
@@ -262,22 +445,22 @@
 <context>
     <name>EditLabelDialog</name>
     <message>
-        <location filename="dialogs.py" line="405"/>
+        <location filename="dialogs.py" line="406"/>
         <source>Edit Label</source>
         <translation>Редактор метки</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="423"/>
+        <location filename="dialogs.py" line="425"/>
         <source>Parent&apos;s color</source>
         <translation>Цвет родителя</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="424"/>
+        <location filename="dialogs.py" line="426"/>
         <source>Choose color</source>
         <translation>Выбор цвета</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="425"/>
+        <location filename="dialogs.py" line="427"/>
         <source>Parent&apos;s font</source>
         <translation>Шрифт родителя</translation>
     </message>
@@ -293,7 +476,7 @@
 <context>
     <name>FontDialog</name>
     <message>
-        <location filename="dialogs.py" line="352"/>
+        <location filename="dialogs.py" line="353"/>
         <source>ABCDE abcde</source>
         <translation>АБВГД абвгд</translation>
     </message>
@@ -319,12 +502,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="256"/>
+        <location filename="dialogs.py" line="257"/>
         <source>&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;center&gt;
                             This application  is licensed under the terms &lt;br&gt;of the
                             &lt;a href=&quot;http://www.gnu.org/licenses/gpl-3.0.html&quot;&gt;
                             GNU General Public License v3&lt;/a&gt;
-                            &lt;p&gt;&lt;br&gt;Copyright &amp;copy; 2010 HiveMind developers&lt;/center&gt;
+                            &lt;p&gt;&lt;br&gt;Copyright &amp;copy; 2010-2011 HiveMind developers&lt;/center&gt;
                             &lt;ul style=&quot;list-style-type: square;margin: 0px 0px 0px 40px&quot;&gt;
                             &lt;li&gt;&lt;a href=&quot;mailto:golovchenkoaa@gmail.com&quot;&gt;Andrey Golovchenko&lt;/a&gt;, core developer
                             &lt;li&gt;&lt;a href=&quot;mailto:vamonster@gmail.com&quot;&gt;Andrey Vasilev&lt;/a&gt;, developer/designer
@@ -335,6 +518,7 @@
                             &lt;a href=&quot;http://fruct.org/&quot;&gt;
                             Open Innovations Framework Program FRUCT&lt;/a&gt;
                             &lt;br&gt;&lt;br&gt;HiveMind logo by &lt;a href=&quot;http://nicubunu.ro&quot;&gt;Nicu Buculei&lt;/a&gt; (nicubunu)
+                            &lt;br&gt;Notification icons by &lt;a href=&quot;http://www.mentalrey.it/&quot;&gt;Mentalrey&lt;/a&gt;
                             &lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;&lt;br&gt;
                             &lt;/center&gt;</source>
         <translation type="unfinished"></translation>
@@ -356,7 +540,7 @@
 <context>
     <name>MaemoMainWindow</name>
     <message>
-        <location filename="main_window.py" line="40"/>
+        <location filename="main_window.py" line="92"/>
         <source>&amp;Full screen</source>
         <translation>&amp;Полный экран</translation>
     </message>
@@ -364,228 +548,58 @@
 <context>
     <name>MaemoSettingsDialog</name>
     <message>
-        <location filename="dialogs.py" line="376"/>
+        <location filename="dialogs.py" line="381"/>
         <source>General</source>
         <translation>Общие</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="377"/>
+        <location filename="dialogs.py" line="382"/>
         <source>Node</source>
         <translation>Узел</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="378"/>
+        <location filename="dialogs.py" line="383"/>
         <source>Edge</source>
         <translation>Ребро</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="379"/>
+        <location filename="dialogs.py" line="384"/>
         <source>Edge Label</source>
         <translation>Метка ребра</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="380"/>
+        <location filename="dialogs.py" line="385"/>
         <source>Animation</source>
         <translation>Анимация</translation>
     </message>
+    <message>
+        <location filename="dialogs.py" line="386"/>
+        <source>Autosave</source>
+        <translation>Автосохранение</translation>
+    </message>
 </context>
 <context>
     <name>MainWindowController</name>
     <message>
-        <location filename="gui_main.py" line="440"/>
-        <source>Open</source>
-        <translation>Открыть</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="465"/>
-        <source>Mind maps (*.mm);;All Files (*)</source>
-        <translation>Диаграммы связей (*.mm);;Все файлы (*)</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="464"/>
-        <source>Save as</source>
-        <translation>Сохранить как</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="183"/>
-        <source>&amp;New</source>
-        <translation>&amp;Создать</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="185"/>
-        <source>&amp;Open</source>
-        <translation>&amp;Открыть</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="187"/>
-        <source>&amp;Save</source>
-        <translation>&amp;Сохранить</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="206"/>
-        <source>&amp;About</source>
-        <translation>&amp;О программе</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="208"/>
-        <source>&amp;Undo</source>
-        <translation>&amp;Отменить</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="211"/>
-        <source>&amp;Redo</source>
-        <translation>&amp;Повторить</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="214"/>
-        <source>E&amp;xit</source>
-        <translation>В&amp;ыход</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="579"/>
+        <location filename="gui_main.py" line="377"/>
         <source>Confirm delete</source>
         <translation>Подтверждение удаления</translation>
     </message>
     <message>
-        <location filename="gui_main.py" line="580"/>
+        <location filename="gui_main.py" line="378"/>
         <source>Do you really want to delete the node?</source>
         <translation>Вы действительно хотите удалить узел?</translation>
     </message>
     <message>
-        <location filename="gui_main.py" line="121"/>
+        <location filename="gui_main.py" line="99"/>
         <source>Unfold node</source>
         <translation>Развернуть поддерево</translation>
     </message>
     <message>
-        <location filename="gui_main.py" line="199"/>
+        <location filename="gui_main.py" line="99"/>
         <source>Fold node</source>
         <translation>Свернуть поддерево</translation>
     </message>
-    <message>
-        <location filename="gui_main.py" line="153"/>
-        <source>Parent</source>
-        <translation>Родителя</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="147"/>
-        <source>Thin</source>
-        <translation>Тонкая</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="155"/>
-        <source>Linear</source>
-        <translation>Прямая</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="157"/>
-        <source>Bezier</source>
-        <translation>Кривая</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="159"/>
-        <source>Sharp linear</source>
-        <translation>Заостр. прямая</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="161"/>
-        <source>Sharp bezier</source>
-        <translation>Заостр. кривая</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="622"/>
-        <source>MindMap has been modified</source>
-        <translation>Диаграмма была изменена</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="623"/>
-        <source>Do you want to save changes?</source>
-        <translation>Сохранить изменения?</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="191"/>
-        <source>Edit edge</source>
-        <translation>Изменить стиль ребра</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="193"/>
-        <source>Edit label</source>
-        <translation>Изменить метку ребра</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="195"/>
-        <source>Edit node</source>
-        <translation>Изменить узел</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="201"/>
-        <source>Add child node</source>
-        <translation>Добавить дочерний узел</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="203"/>
-        <source>Remove node</source>
-        <translation>Удалить узел</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="205"/>
-        <source>Move node</source>
-        <translation>Переместить узел</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="216"/>
-        <source>&amp;Share mind map</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="218"/>
-        <source>&amp;Edit shared mind map</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="220"/>
-        <source>&amp;Finish collaboration</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="223"/>
-        <source>Settings</source>
-        <translation>Настройки</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="197"/>
-        <source>Select icons</source>
-        <translation>Выбрать пиктограммы</translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="677"/>
-        <source>Connection problem</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="678"/>
-        <source>Connection with XMPP server can not be established!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="680"/>
-        <source>Subscription problem</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="681"/>
-        <source>Subscription error. You are disconnected.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="683"/>
-        <source>Unknown problem</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="gui_main.py" line="684"/>
-        <source>Unknown problem has occured. You are disconnected.</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MindMap</name>
@@ -595,83 +609,179 @@
         <translation>Корень</translation>
     </message>
 </context>
+<context>
+    <name>MindMapController</name>
+    <message>
+        <location filename="gui_main.py" line="506"/>
+        <source>Open</source>
+        <translation>Открыть</translation>
+    </message>
+    <message>
+        <location filename="gui_main.py" line="535"/>
+        <source>Mind maps (*.mm);;All Files (*)</source>
+        <translation>Диаграммы связей (*.mm);;Все файлы (*)</translation>
+    </message>
+    <message>
+        <location filename="gui_main.py" line="544"/>
+        <source>File save error</source>
+        <translation type="unfinished">Ошибка сохранения файла</translation>
+    </message>
+    <message>
+        <location filename="gui_main.py" line="534"/>
+        <source>Save as</source>
+        <translation type="unfinished">Сохранить как</translation>
+    </message>
+    <message>
+        <location filename="gui_main.py" line="574"/>
+        <source>Save changes?</source>
+        <translation>Сохранить изменения?</translation>
+    </message>
+    <message>
+        <location filename="gui_main.py" line="575"/>
+        <source>MindMap has been modified</source>
+        <translation>Диаграмма была изменена</translation>
+    </message>
+    <message>
+        <location filename="gui_main.py" line="578"/>
+        <source>Do you want to save changes?</source>
+        <translation>Сохранить изменения?</translation>
+    </message>
+    <message>
+        <location filename="gui_main.py" line="654"/>
+        <source>File open error</source>
+        <translation type="unfinished">Ошибка открытия файла</translation>
+    </message>
+    <message>
+        <location filename="gui_main.py" line="671"/>
+        <source>Autosaved data recovery</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="gui_main.py" line="673"/>
+        <source>File %s has automatically saved data. Recover it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="gui_main.py" line="655"/>
+        <source>Cannot read mind map from file %s</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>NetworkController</name>
+    <message>
+        <location filename="network_core.py" line="313"/>
+        <source>Subscription error. You are disconnected.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="network_core.py" line="306"/>
+        <source>Authorization failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="network_core.py" line="307"/>
+        <source>Incorrect login/password. You are disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="network_core.py" line="312"/>
+        <source>Subscription failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SettingsCreator</name>
     <message>
-        <location filename="gui_widgets.py" line="530"/>
+        <location filename="gui_widgets.py" line="620"/>
         <source>Language</source>
         <translation>Язык</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="647"/>
+        <location filename="gui_widgets.py" line="743"/>
         <source>Thin</source>
         <translation>Тонкая</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="659"/>
+        <location filename="gui_widgets.py" line="755"/>
         <source>Choose color</source>
         <translation>Выбор цвета</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="625"/>
+        <location filename="gui_widgets.py" line="721"/>
         <source>Edge color</source>
         <translation>Цвет ребра</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="639"/>
+        <location filename="gui_widgets.py" line="735"/>
         <source>Label color</source>
         <translation>Цвет метки</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="650"/>
+        <location filename="gui_widgets.py" line="746"/>
         <source>Edge width</source>
         <translation>Толщина ребра</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="549"/>
+        <location filename="gui_widgets.py" line="639"/>
         <source>Menu hide timeout</source>
         <translation>Таймаут сокрытия меню</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="558"/>
+        <location filename="gui_widgets.py" line="648"/>
         <source>Menu appearance duration</source>
         <translation>Длительность появления меню</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="567"/>
+        <location filename="gui_widgets.py" line="657"/>
         <source>Menu disappearance duration</source>
         <translation>Длительность исчезновения меню</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="575"/>
+        <location filename="gui_widgets.py" line="668"/>
         <source>Text font</source>
         <translation>Шрифт текста</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="584"/>
+        <location filename="gui_widgets.py" line="680"/>
         <source>Label font</source>
         <translation>Шрифт метки</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="597"/>
+        <location filename="gui_widgets.py" line="693"/>
         <source>Text color</source>
         <translation>Цвет текста</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="611"/>
+        <location filename="gui_widgets.py" line="707"/>
         <source>Background color</source>
         <translation>Цвет фона</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="663"/>
+        <location filename="gui_widgets.py" line="759"/>
         <source>Selected node background</source>
         <translation>Фон выбранного узла</translation>
     </message>
     <message>
-        <location filename="gui_widgets.py" line="539"/>
+        <location filename="gui_widgets.py" line="629"/>
         <source>Confirm node deletion</source>
         <translation>Подтверждать удаление узла</translation>
     </message>
+    <message>
+        <location filename="gui_widgets.py" line="768"/>
+        <source>Enable autosave of mind map</source>
+        <translation>Включить автоматическое сохранение файла диаграммы связей</translation>
+    </message>
+    <message>
+        <location filename="gui_widgets.py" line="779"/>
+        <source>Autosave interval</source>
+        <translation>Интервал автоматического сохранения</translation>
+    </message>
+    <message>
+        <location filename="gui_widgets.py" line="778"/>
+        <source> sec</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsDialog</name>
@@ -681,12 +791,12 @@
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="855"/>
+        <location filename="dialogs.py" line="857"/>
         <source>Settings changed</source>
         <translation>Настройки изменены</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="856"/>
+        <location filename="dialogs.py" line="858"/>
         <source>The language settings will be applied on restart of the application!</source>
         <translation>Настройки языка вступят в силу после перезапуска приложения!</translation>
     </message>
@@ -694,22 +804,22 @@
 <context>
     <name>SideSelectionDialog</name>
     <message>
-        <location filename="dialogs.py" line="937"/>
+        <location filename="dialogs.py" line="945"/>
         <source>Node Position</source>
         <translation>Положение узла</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="946"/>
+        <location filename="dialogs.py" line="954"/>
         <source>Select node position</source>
         <translation>Выберите положение узла</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="947"/>
+        <location filename="dialogs.py" line="955"/>
         <source>Left</source>
         <translation>Слева</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="948"/>
+        <location filename="dialogs.py" line="956"/>
         <source>Right</source>
         <translation>Справа</translation>
     </message>
@@ -717,34 +827,39 @@
 <context>
     <name>XMPPCredentialsDialog</name>
     <message>
-        <location filename="dialogs.py" line="870"/>
+        <location filename="dialogs.py" line="872"/>
         <source>XMPP Credentials</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="881"/>
+        <location filename="dialogs.py" line="883"/>
         <source>User JID:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="884"/>
+        <location filename="dialogs.py" line="886"/>
         <source>Password:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="886"/>
+        <location filename="dialogs.py" line="888"/>
         <source>Service JID:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="905"/>
+        <location filename="dialogs.py" line="911"/>
         <source>Incorrect JID!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="906"/>
+        <location filename="dialogs.py" line="912"/>
         <source>Please, enter correct jabber id.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="dialogs.py" line="890"/>
+        <source>Read only</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
